# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class GetUserResult:
    """
    A collection of values returned by getUser.
    """
    def __init__(__self__, admin_roles=None, city=None, cost_center=None, country_code=None, custom_profile_attributes=None, department=None, display_name=None, division=None, email=None, employee_number=None, first_name=None, group_memberships=None, honorific_prefix=None, honorific_suffix=None, id=None, last_name=None, locale=None, login=None, manager=None, manager_id=None, middle_name=None, mobile_phone=None, nick_name=None, organization=None, postal_address=None, preferred_language=None, primary_phone=None, profile_url=None, searches=None, second_email=None, state=None, status=None, street_address=None, timezone=None, title=None, user_type=None, zip_code=None):
        if admin_roles and not isinstance(admin_roles, list):
            raise TypeError("Expected argument 'admin_roles' to be a list")
        __self__.admin_roles = admin_roles
        """
        Administrator roles assigned to user.
        """
        if city and not isinstance(city, str):
            raise TypeError("Expected argument 'city' to be a str")
        __self__.city = city
        """
        user profile property.
        """
        if cost_center and not isinstance(cost_center, str):
            raise TypeError("Expected argument 'cost_center' to be a str")
        __self__.cost_center = cost_center
        """
        user profile property.
        """
        if country_code and not isinstance(country_code, str):
            raise TypeError("Expected argument 'country_code' to be a str")
        __self__.country_code = country_code
        """
        user profile property.
        """
        if custom_profile_attributes and not isinstance(custom_profile_attributes, str):
            raise TypeError("Expected argument 'custom_profile_attributes' to be a str")
        __self__.custom_profile_attributes = custom_profile_attributes
        """
        raw JSON containing all custom profile attributes.
        """
        if department and not isinstance(department, str):
            raise TypeError("Expected argument 'department' to be a str")
        __self__.department = department
        """
        user profile property.
        """
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        __self__.display_name = display_name
        """
        user profile property.
        """
        if division and not isinstance(division, str):
            raise TypeError("Expected argument 'division' to be a str")
        __self__.division = division
        """
        user profile property.
        """
        if email and not isinstance(email, str):
            raise TypeError("Expected argument 'email' to be a str")
        __self__.email = email
        """
        user profile property.
        """
        if employee_number and not isinstance(employee_number, str):
            raise TypeError("Expected argument 'employee_number' to be a str")
        __self__.employee_number = employee_number
        """
        user profile property.
        """
        if first_name and not isinstance(first_name, str):
            raise TypeError("Expected argument 'first_name' to be a str")
        __self__.first_name = first_name
        """
        user profile property.
        """
        if group_memberships and not isinstance(group_memberships, list):
            raise TypeError("Expected argument 'group_memberships' to be a list")
        __self__.group_memberships = group_memberships
        """
        user profile property.
        """
        if honorific_prefix and not isinstance(honorific_prefix, str):
            raise TypeError("Expected argument 'honorific_prefix' to be a str")
        __self__.honorific_prefix = honorific_prefix
        """
        user profile property.
        """
        if honorific_suffix and not isinstance(honorific_suffix, str):
            raise TypeError("Expected argument 'honorific_suffix' to be a str")
        __self__.honorific_suffix = honorific_suffix
        """
        user profile property.
        """
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        The provider-assigned unique ID for this managed resource.
        """
        if last_name and not isinstance(last_name, str):
            raise TypeError("Expected argument 'last_name' to be a str")
        __self__.last_name = last_name
        """
        user profile property.
        """
        if locale and not isinstance(locale, str):
            raise TypeError("Expected argument 'locale' to be a str")
        __self__.locale = locale
        """
        user profile property.
        """
        if login and not isinstance(login, str):
            raise TypeError("Expected argument 'login' to be a str")
        __self__.login = login
        """
        user profile property.
        """
        if manager and not isinstance(manager, str):
            raise TypeError("Expected argument 'manager' to be a str")
        __self__.manager = manager
        """
        user profile property.
        """
        if manager_id and not isinstance(manager_id, str):
            raise TypeError("Expected argument 'manager_id' to be a str")
        __self__.manager_id = manager_id
        """
        user profile property.
        """
        if middle_name and not isinstance(middle_name, str):
            raise TypeError("Expected argument 'middle_name' to be a str")
        __self__.middle_name = middle_name
        """
        user profile property.
        """
        if mobile_phone and not isinstance(mobile_phone, str):
            raise TypeError("Expected argument 'mobile_phone' to be a str")
        __self__.mobile_phone = mobile_phone
        """
        user profile property.
        """
        if nick_name and not isinstance(nick_name, str):
            raise TypeError("Expected argument 'nick_name' to be a str")
        __self__.nick_name = nick_name
        """
        user profile property.
        """
        if organization and not isinstance(organization, str):
            raise TypeError("Expected argument 'organization' to be a str")
        __self__.organization = organization
        """
        user profile property.
        """
        if postal_address and not isinstance(postal_address, str):
            raise TypeError("Expected argument 'postal_address' to be a str")
        __self__.postal_address = postal_address
        """
        user profile property.
        """
        if preferred_language and not isinstance(preferred_language, str):
            raise TypeError("Expected argument 'preferred_language' to be a str")
        __self__.preferred_language = preferred_language
        """
        user profile property.
        """
        if primary_phone and not isinstance(primary_phone, str):
            raise TypeError("Expected argument 'primary_phone' to be a str")
        __self__.primary_phone = primary_phone
        """
        user profile property.
        """
        if profile_url and not isinstance(profile_url, str):
            raise TypeError("Expected argument 'profile_url' to be a str")
        __self__.profile_url = profile_url
        """
        user profile property.
        """
        if searches and not isinstance(searches, list):
            raise TypeError("Expected argument 'searches' to be a list")
        __self__.searches = searches
        if second_email and not isinstance(second_email, str):
            raise TypeError("Expected argument 'second_email' to be a str")
        __self__.second_email = second_email
        """
        user profile property.
        """
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        __self__.state = state
        """
        user profile property.
        """
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        __self__.status = status
        """
        user profile property.
        """
        if street_address and not isinstance(street_address, str):
            raise TypeError("Expected argument 'street_address' to be a str")
        __self__.street_address = street_address
        """
        user profile property.
        """
        if timezone and not isinstance(timezone, str):
            raise TypeError("Expected argument 'timezone' to be a str")
        __self__.timezone = timezone
        """
        user profile property.
        """
        if title and not isinstance(title, str):
            raise TypeError("Expected argument 'title' to be a str")
        __self__.title = title
        """
        user profile property.
        """
        if user_type and not isinstance(user_type, str):
            raise TypeError("Expected argument 'user_type' to be a str")
        __self__.user_type = user_type
        """
        user profile property.
        """
        if zip_code and not isinstance(zip_code, str):
            raise TypeError("Expected argument 'zip_code' to be a str")
        __self__.zip_code = zip_code
        """
        user profile property.
        """
class AwaitableGetUserResult(GetUserResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetUserResult(
            admin_roles=self.admin_roles,
            city=self.city,
            cost_center=self.cost_center,
            country_code=self.country_code,
            custom_profile_attributes=self.custom_profile_attributes,
            department=self.department,
            display_name=self.display_name,
            division=self.division,
            email=self.email,
            employee_number=self.employee_number,
            first_name=self.first_name,
            group_memberships=self.group_memberships,
            honorific_prefix=self.honorific_prefix,
            honorific_suffix=self.honorific_suffix,
            id=self.id,
            last_name=self.last_name,
            locale=self.locale,
            login=self.login,
            manager=self.manager,
            manager_id=self.manager_id,
            middle_name=self.middle_name,
            mobile_phone=self.mobile_phone,
            nick_name=self.nick_name,
            organization=self.organization,
            postal_address=self.postal_address,
            preferred_language=self.preferred_language,
            primary_phone=self.primary_phone,
            profile_url=self.profile_url,
            searches=self.searches,
            second_email=self.second_email,
            state=self.state,
            status=self.status,
            street_address=self.street_address,
            timezone=self.timezone,
            title=self.title,
            user_type=self.user_type,
            zip_code=self.zip_code)

def get_user(searches=None,opts=None):
    """
    Use this data source to retrieve a users from Okta.

    ## Example Usage



    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.user.get_user(searches=[
        {
            "name": "profile.firstName",
            "value": "John",
        },
        {
            "name": "profile.lastName",
            "value": "Doe",
        },
    ])
    ```



    :param list searches: Map of search criteria. It supports the following properties.

    The **searches** object supports the following:

      * `comparison` (`str`) - Comparison to use.
      * `name` (`str`) - Name of property to search against.
      * `value` (`str`) - Value to compare with.
    """
    __args__ = dict()


    __args__['searches'] = searches
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('okta:user/getUser:getUser', __args__, opts=opts).value

    return AwaitableGetUserResult(
        admin_roles=__ret__.get('adminRoles'),
        city=__ret__.get('city'),
        cost_center=__ret__.get('costCenter'),
        country_code=__ret__.get('countryCode'),
        custom_profile_attributes=__ret__.get('customProfileAttributes'),
        department=__ret__.get('department'),
        display_name=__ret__.get('displayName'),
        division=__ret__.get('division'),
        email=__ret__.get('email'),
        employee_number=__ret__.get('employeeNumber'),
        first_name=__ret__.get('firstName'),
        group_memberships=__ret__.get('groupMemberships'),
        honorific_prefix=__ret__.get('honorificPrefix'),
        honorific_suffix=__ret__.get('honorificSuffix'),
        id=__ret__.get('id'),
        last_name=__ret__.get('lastName'),
        locale=__ret__.get('locale'),
        login=__ret__.get('login'),
        manager=__ret__.get('manager'),
        manager_id=__ret__.get('managerId'),
        middle_name=__ret__.get('middleName'),
        mobile_phone=__ret__.get('mobilePhone'),
        nick_name=__ret__.get('nickName'),
        organization=__ret__.get('organization'),
        postal_address=__ret__.get('postalAddress'),
        preferred_language=__ret__.get('preferredLanguage'),
        primary_phone=__ret__.get('primaryPhone'),
        profile_url=__ret__.get('profileUrl'),
        searches=__ret__.get('searches'),
        second_email=__ret__.get('secondEmail'),
        state=__ret__.get('state'),
        status=__ret__.get('status'),
        street_address=__ret__.get('streetAddress'),
        timezone=__ret__.get('timezone'),
        title=__ret__.get('title'),
        user_type=__ret__.get('userType'),
        zip_code=__ret__.get('zipCode'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class RuleIdpDiscovery(pulumi.CustomResource):
    app_excludes: pulumi.Output[list]
    """
    Applications to exclude in discovery rule

      * `id` (`str`) - ID of the Rule.
      * `name` (`str`) - Policy Rule Name.
      * `type` (`str`)
    """
    app_includes: pulumi.Output[list]
    """
    Applications to include in discovery rule

      * `id` (`str`) - ID of the Rule.
      * `name` (`str`) - Policy Rule Name.
      * `type` (`str`)
    """
    idp_id: pulumi.Output[str]
    idp_type: pulumi.Output[str]
    name: pulumi.Output[str]
    """
    Policy Rule Name.
    """
    network_connection: pulumi.Output[str]
    """
    Network selection mode: `"ANYWHERE"`, `"ZONE"`, `"ON_NETWORK"`, or `"OFF_NETWORK"`.
    """
    network_excludes: pulumi.Output[list]
    """
    The network zones to exclude. Conflicts with `network_includes`.
    """
    network_includes: pulumi.Output[list]
    """
    The network zones to include. Conflicts with `network_excludes`.
    """
    platform_includes: pulumi.Output[list]
    policyid: pulumi.Output[str]
    """
    Policy ID.
    """
    priority: pulumi.Output[float]
    """
    Policy Rule Priority, this attribute can be set to a valid priority. To avoid endless diff situation we error if an invalid priority is provided. API defaults it to the last/lowest if not there.
    """
    status: pulumi.Output[str]
    """
    Policy Rule Status: `"ACTIVE"` or `"INACTIVE"`.
    """
    user_identifier_attribute: pulumi.Output[str]
    user_identifier_patterns: pulumi.Output[list]
    user_identifier_type: pulumi.Output[str]
    def __init__(__self__, resource_name, opts=None, app_excludes=None, app_includes=None, idp_id=None, idp_type=None, name=None, network_connection=None, network_excludes=None, network_includes=None, platform_includes=None, policyid=None, priority=None, status=None, user_identifier_attribute=None, user_identifier_patterns=None, user_identifier_type=None, __props__=None, __name__=None, __opts__=None):
        """
        Creates an IdP Discovery Policy Rule.

        This resource allows you to create and configure an IdP Discovery Policy Rule.

        ## Example Usage



        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.policy.RuleIdpDiscovery("example",
            idp_id="<idp id>",
            idp_type="SAML2",
            policyid="<policy id>",
            priority=1,
            user_identifier_attribute="company",
            user_identifier_patterns=[{
                "matchType": "EQUALS",
                "value": "Articulate",
            }],
            user_identifier_type="ATTRIBUTE")
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] app_excludes: Applications to exclude in discovery rule
        :param pulumi.Input[list] app_includes: Applications to include in discovery rule
        :param pulumi.Input[str] name: Policy Rule Name.
        :param pulumi.Input[str] network_connection: Network selection mode: `"ANYWHERE"`, `"ZONE"`, `"ON_NETWORK"`, or `"OFF_NETWORK"`.
        :param pulumi.Input[list] network_excludes: The network zones to exclude. Conflicts with `network_includes`.
        :param pulumi.Input[list] network_includes: The network zones to include. Conflicts with `network_excludes`.
        :param pulumi.Input[str] policyid: Policy ID.
        :param pulumi.Input[float] priority: Policy Rule Priority, this attribute can be set to a valid priority. To avoid endless diff situation we error if an invalid priority is provided. API defaults it to the last/lowest if not there.
        :param pulumi.Input[str] status: Policy Rule Status: `"ACTIVE"` or `"INACTIVE"`.

        The **app_excludes** object supports the following:

          * `id` (`pulumi.Input[str]`) - ID of the Rule.
          * `name` (`pulumi.Input[str]`) - Policy Rule Name.
          * `type` (`pulumi.Input[str]`)

        The **app_includes** object supports the following:

          * `id` (`pulumi.Input[str]`) - ID of the Rule.
          * `name` (`pulumi.Input[str]`) - Policy Rule Name.
          * `type` (`pulumi.Input[str]`)

        The **platform_includes** object supports the following:

          * `osExpression` (`pulumi.Input[str]`)
          * `osType` (`pulumi.Input[str]`)
          * `type` (`pulumi.Input[str]`)

        The **user_identifier_patterns** object supports the following:

          * `match_type` (`pulumi.Input[str]`)
          * `value` (`pulumi.Input[str]`)
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['app_excludes'] = app_excludes
            __props__['app_includes'] = app_includes
            __props__['idp_id'] = idp_id
            __props__['idp_type'] = idp_type
            __props__['name'] = name
            __props__['network_connection'] = network_connection
            __props__['network_excludes'] = network_excludes
            __props__['network_includes'] = network_includes
            __props__['platform_includes'] = platform_includes
            if policyid is None:
                raise TypeError("Missing required property 'policyid'")
            __props__['policyid'] = policyid
            __props__['priority'] = priority
            __props__['status'] = status
            __props__['user_identifier_attribute'] = user_identifier_attribute
            __props__['user_identifier_patterns'] = user_identifier_patterns
            __props__['user_identifier_type'] = user_identifier_type
        super(RuleIdpDiscovery, __self__).__init__(
            'okta:policy/ruleIdpDiscovery:RuleIdpDiscovery',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, app_excludes=None, app_includes=None, idp_id=None, idp_type=None, name=None, network_connection=None, network_excludes=None, network_includes=None, platform_includes=None, policyid=None, priority=None, status=None, user_identifier_attribute=None, user_identifier_patterns=None, user_identifier_type=None):
        """
        Get an existing RuleIdpDiscovery resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] app_excludes: Applications to exclude in discovery rule
        :param pulumi.Input[list] app_includes: Applications to include in discovery rule
        :param pulumi.Input[str] name: Policy Rule Name.
        :param pulumi.Input[str] network_connection: Network selection mode: `"ANYWHERE"`, `"ZONE"`, `"ON_NETWORK"`, or `"OFF_NETWORK"`.
        :param pulumi.Input[list] network_excludes: The network zones to exclude. Conflicts with `network_includes`.
        :param pulumi.Input[list] network_includes: The network zones to include. Conflicts with `network_excludes`.
        :param pulumi.Input[str] policyid: Policy ID.
        :param pulumi.Input[float] priority: Policy Rule Priority, this attribute can be set to a valid priority. To avoid endless diff situation we error if an invalid priority is provided. API defaults it to the last/lowest if not there.
        :param pulumi.Input[str] status: Policy Rule Status: `"ACTIVE"` or `"INACTIVE"`.

        The **app_excludes** object supports the following:

          * `id` (`pulumi.Input[str]`) - ID of the Rule.
          * `name` (`pulumi.Input[str]`) - Policy Rule Name.
          * `type` (`pulumi.Input[str]`)

        The **app_includes** object supports the following:

          * `id` (`pulumi.Input[str]`) - ID of the Rule.
          * `name` (`pulumi.Input[str]`) - Policy Rule Name.
          * `type` (`pulumi.Input[str]`)

        The **platform_includes** object supports the following:

          * `osExpression` (`pulumi.Input[str]`)
          * `osType` (`pulumi.Input[str]`)
          * `type` (`pulumi.Input[str]`)

        The **user_identifier_patterns** object supports the following:

          * `match_type` (`pulumi.Input[str]`)
          * `value` (`pulumi.Input[str]`)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["app_excludes"] = app_excludes
        __props__["app_includes"] = app_includes
        __props__["idp_id"] = idp_id
        __props__["idp_type"] = idp_type
        __props__["name"] = name
        __props__["network_connection"] = network_connection
        __props__["network_excludes"] = network_excludes
        __props__["network_includes"] = network_includes
        __props__["platform_includes"] = platform_includes
        __props__["policyid"] = policyid
        __props__["priority"] = priority
        __props__["status"] = status
        __props__["user_identifier_attribute"] = user_identifier_attribute
        __props__["user_identifier_patterns"] = user_identifier_patterns
        __props__["user_identifier_type"] = user_identifier_type
        return RuleIdpDiscovery(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class SecurePasswordStoreApp(pulumi.CustomResource):
    accessibility_error_redirect_url: pulumi.Output[str]
    """
    Custom error page URL
    """
    accessibility_self_service: pulumi.Output[bool]
    """
    Enable self service
    """
    auto_submit_toolbar: pulumi.Output[bool]
    """
    Display auto submit toolbar
    """
    credentials_scheme: pulumi.Output[str]
    """
    Application credentials scheme
    """
    groups: pulumi.Output[list]
    """
    Groups associated with the application
    """
    hide_ios: pulumi.Output[bool]
    """
    Do not display application icon on mobile app
    """
    hide_web: pulumi.Output[bool]
    """
    Do not display application icon to users
    """
    label: pulumi.Output[str]
    """
    Pretty name of app.
    """
    name: pulumi.Output[str]
    """
    name of app.
    """
    optional_field1: pulumi.Output[str]
    """
    Name of optional param in the login form
    """
    optional_field1_value: pulumi.Output[str]
    """
    Name of optional value in login form
    """
    optional_field2: pulumi.Output[str]
    """
    Name of optional param in the login form
    """
    optional_field2_value: pulumi.Output[str]
    """
    Name of optional value in login form
    """
    optional_field3: pulumi.Output[str]
    """
    Name of optional param in the login form
    """
    optional_field3_value: pulumi.Output[str]
    """
    Name of optional value in login form
    """
    password_field: pulumi.Output[str]
    """
    Login password field
    """
    reveal_password: pulumi.Output[bool]
    """
    Allow user to reveal password
    """
    shared_password: pulumi.Output[str]
    """
    Shared password, required for certain schemes.
    """
    shared_username: pulumi.Output[str]
    """
    Shared username, required for certain schemes.
    """
    sign_on_mode: pulumi.Output[str]
    """
    Sign on mode of application.
    """
    status: pulumi.Output[str]
    """
    Status of application.
    """
    url: pulumi.Output[str]
    """
    Login URL
    """
    user_name_template: pulumi.Output[str]
    """
    Username template
    """
    user_name_template_type: pulumi.Output[str]
    """
    Username template type
    """
    username_field: pulumi.Output[str]
    """
    Login username field
    """
    users: pulumi.Output[list]
    """
    Users associated with the application

      * `id` (`str`)
      * `password` (`str`)
      * `scope` (`str`)
      * `username` (`str`)
    """
    def __init__(__self__, resource_name, opts=None, accessibility_error_redirect_url=None, accessibility_self_service=None, auto_submit_toolbar=None, credentials_scheme=None, groups=None, hide_ios=None, hide_web=None, label=None, optional_field1=None, optional_field1_value=None, optional_field2=None, optional_field2_value=None, optional_field3=None, optional_field3_value=None, password_field=None, reveal_password=None, shared_password=None, shared_username=None, status=None, url=None, username_field=None, users=None, __props__=None, __name__=None, __opts__=None):
        """
        Create a SecurePasswordStoreApp resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] accessibility_error_redirect_url: Custom error page URL
        :param pulumi.Input[bool] accessibility_self_service: Enable self service
        :param pulumi.Input[bool] auto_submit_toolbar: Display auto submit toolbar
        :param pulumi.Input[str] credentials_scheme: Application credentials scheme
        :param pulumi.Input[list] groups: Groups associated with the application
        :param pulumi.Input[bool] hide_ios: Do not display application icon on mobile app
        :param pulumi.Input[bool] hide_web: Do not display application icon to users
        :param pulumi.Input[str] label: Pretty name of app.
        :param pulumi.Input[str] optional_field1: Name of optional param in the login form
        :param pulumi.Input[str] optional_field1_value: Name of optional value in login form
        :param pulumi.Input[str] optional_field2: Name of optional param in the login form
        :param pulumi.Input[str] optional_field2_value: Name of optional value in login form
        :param pulumi.Input[str] optional_field3: Name of optional param in the login form
        :param pulumi.Input[str] optional_field3_value: Name of optional value in login form
        :param pulumi.Input[str] password_field: Login password field
        :param pulumi.Input[bool] reveal_password: Allow user to reveal password
        :param pulumi.Input[str] shared_password: Shared password, required for certain schemes.
        :param pulumi.Input[str] shared_username: Shared username, required for certain schemes.
        :param pulumi.Input[str] status: Status of application.
        :param pulumi.Input[str] url: Login URL
        :param pulumi.Input[str] username_field: Login username field
        :param pulumi.Input[list] users: Users associated with the application

        The **users** object supports the following:

          * `id` (`pulumi.Input[str]`)
          * `password` (`pulumi.Input[str]`)
          * `scope` (`pulumi.Input[str]`)
          * `username` (`pulumi.Input[str]`)
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['accessibility_error_redirect_url'] = accessibility_error_redirect_url
            __props__['accessibility_self_service'] = accessibility_self_service
            __props__['auto_submit_toolbar'] = auto_submit_toolbar
            __props__['credentials_scheme'] = credentials_scheme
            __props__['groups'] = groups
            __props__['hide_ios'] = hide_ios
            __props__['hide_web'] = hide_web
            if label is None:
                raise TypeError("Missing required property 'label'")
            __props__['label'] = label
            __props__['optional_field1'] = optional_field1
            __props__['optional_field1_value'] = optional_field1_value
            __props__['optional_field2'] = optional_field2
            __props__['optional_field2_value'] = optional_field2_value
            __props__['optional_field3'] = optional_field3
            __props__['optional_field3_value'] = optional_field3_value
            if password_field is None:
                raise TypeError("Missing required property 'password_field'")
            __props__['password_field'] = password_field
            __props__['reveal_password'] = reveal_password
            __props__['shared_password'] = shared_password
            __props__['shared_username'] = shared_username
            __props__['status'] = status
            if url is None:
                raise TypeError("Missing required property 'url'")
            __props__['url'] = url
            if username_field is None:
                raise TypeError("Missing required property 'username_field'")
            __props__['username_field'] = username_field
            __props__['users'] = users
            __props__['name'] = None
            __props__['sign_on_mode'] = None
            __props__['user_name_template'] = None
            __props__['user_name_template_type'] = None
        super(SecurePasswordStoreApp, __self__).__init__(
            'okta:deprecated/securePasswordStoreApp:SecurePasswordStoreApp',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, accessibility_error_redirect_url=None, accessibility_self_service=None, auto_submit_toolbar=None, credentials_scheme=None, groups=None, hide_ios=None, hide_web=None, label=None, name=None, optional_field1=None, optional_field1_value=None, optional_field2=None, optional_field2_value=None, optional_field3=None, optional_field3_value=None, password_field=None, reveal_password=None, shared_password=None, shared_username=None, sign_on_mode=None, status=None, url=None, user_name_template=None, user_name_template_type=None, username_field=None, users=None):
        """
        Get an existing SecurePasswordStoreApp resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] accessibility_error_redirect_url: Custom error page URL
        :param pulumi.Input[bool] accessibility_self_service: Enable self service
        :param pulumi.Input[bool] auto_submit_toolbar: Display auto submit toolbar
        :param pulumi.Input[str] credentials_scheme: Application credentials scheme
        :param pulumi.Input[list] groups: Groups associated with the application
        :param pulumi.Input[bool] hide_ios: Do not display application icon on mobile app
        :param pulumi.Input[bool] hide_web: Do not display application icon to users
        :param pulumi.Input[str] label: Pretty name of app.
        :param pulumi.Input[str] name: name of app.
        :param pulumi.Input[str] optional_field1: Name of optional param in the login form
        :param pulumi.Input[str] optional_field1_value: Name of optional value in login form
        :param pulumi.Input[str] optional_field2: Name of optional param in the login form
        :param pulumi.Input[str] optional_field2_value: Name of optional value in login form
        :param pulumi.Input[str] optional_field3: Name of optional param in the login form
        :param pulumi.Input[str] optional_field3_value: Name of optional value in login form
        :param pulumi.Input[str] password_field: Login password field
        :param pulumi.Input[bool] reveal_password: Allow user to reveal password
        :param pulumi.Input[str] shared_password: Shared password, required for certain schemes.
        :param pulumi.Input[str] shared_username: Shared username, required for certain schemes.
        :param pulumi.Input[str] sign_on_mode: Sign on mode of application.
        :param pulumi.Input[str] status: Status of application.
        :param pulumi.Input[str] url: Login URL
        :param pulumi.Input[str] user_name_template: Username template
        :param pulumi.Input[str] user_name_template_type: Username template type
        :param pulumi.Input[str] username_field: Login username field
        :param pulumi.Input[list] users: Users associated with the application

        The **users** object supports the following:

          * `id` (`pulumi.Input[str]`)
          * `password` (`pulumi.Input[str]`)
          * `scope` (`pulumi.Input[str]`)
          * `username` (`pulumi.Input[str]`)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["accessibility_error_redirect_url"] = accessibility_error_redirect_url
        __props__["accessibility_self_service"] = accessibility_self_service
        __props__["auto_submit_toolbar"] = auto_submit_toolbar
        __props__["credentials_scheme"] = credentials_scheme
        __props__["groups"] = groups
        __props__["hide_ios"] = hide_ios
        __props__["hide_web"] = hide_web
        __props__["label"] = label
        __props__["name"] = name
        __props__["optional_field1"] = optional_field1
        __props__["optional_field1_value"] = optional_field1_value
        __props__["optional_field2"] = optional_field2
        __props__["optional_field2_value"] = optional_field2_value
        __props__["optional_field3"] = optional_field3
        __props__["optional_field3_value"] = optional_field3_value
        __props__["password_field"] = password_field
        __props__["reveal_password"] = reveal_password
        __props__["shared_password"] = shared_password
        __props__["shared_username"] = shared_username
        __props__["sign_on_mode"] = sign_on_mode
        __props__["status"] = status
        __props__["url"] = url
        __props__["user_name_template"] = user_name_template
        __props__["user_name_template_type"] = user_name_template_type
        __props__["username_field"] = username_field
        __props__["users"] = users
        return SecurePasswordStoreApp(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class Mapping(pulumi.CustomResource):
    delete_when_absent: pulumi.Output[bool]
    """
    When turned on this flag will trigger the provider to delete mapping properties that are not defined in config. By
    default, we do not delete missing properties.
    """
    mappings: pulumi.Output[list]
    source_id: pulumi.Output[str]
    """
    The source id of the mapping to manage.
    """
    source_name: pulumi.Output[str]
    source_type: pulumi.Output[str]
    target_id: pulumi.Output[str]
    """
    The target id of the mapping to manage.
    """
    target_name: pulumi.Output[str]
    target_type: pulumi.Output[str]
    def __init__(__self__, resource_name, opts=None, delete_when_absent=None, mappings=None, source_id=None, target_id=None, __props__=None, __name__=None, __opts__=None):
        """
        Create a Mapping resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] delete_when_absent: When turned on this flag will trigger the provider to delete mapping properties that are not defined in config. By
               default, we do not delete missing properties.
        :param pulumi.Input[str] source_id: The source id of the mapping to manage.
        :param pulumi.Input[str] target_id: The target id of the mapping to manage.

        The **mappings** object supports the following:

          * `expression` (`pulumi.Input[str]`)
          * `id` (`pulumi.Input[str]`)
          * `pushStatus` (`pulumi.Input[str]`)
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['delete_when_absent'] = delete_when_absent
            __props__['mappings'] = mappings
            if source_id is None:
                raise TypeError("Missing required property 'source_id'")
            __props__['source_id'] = source_id
            if target_id is None:
                raise TypeError("Missing required property 'target_id'")
            __props__['target_id'] = target_id
            __props__['source_name'] = None
            __props__['source_type'] = None
            __props__['target_name'] = None
            __props__['target_type'] = None
        super(Mapping, __self__).__init__(
            'okta:profile/mapping:Mapping',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, delete_when_absent=None, mappings=None, source_id=None, source_name=None, source_type=None, target_id=None, target_name=None, target_type=None):
        """
        Get an existing Mapping resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] delete_when_absent: When turned on this flag will trigger the provider to delete mapping properties that are not defined in config. By
               default, we do not delete missing properties.
        :param pulumi.Input[str] source_id: The source id of the mapping to manage.
        :param pulumi.Input[str] target_id: The target id of the mapping to manage.

        The **mappings** object supports the following:

          * `expression` (`pulumi.Input[str]`)
          * `id` (`pulumi.Input[str]`)
          * `pushStatus` (`pulumi.Input[str]`)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["delete_when_absent"] = delete_when_absent
        __props__["mappings"] = mappings
        __props__["source_id"] = source_id
        __props__["source_name"] = source_name
        __props__["source_type"] = source_type
        __props__["target_id"] = target_id
        __props__["target_name"] = target_name
        __props__["target_type"] = target_type
        return Mapping(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class Zone(pulumi.CustomResource):
    dynamic_locations: pulumi.Output[list]
    """
    Array of locations ISO-3166-1(2). Format code: countryCode OR countryCode-regionCode.
    """
    gateways: pulumi.Output[list]
    """
    Array of values in CIDR/range form.
    """
    name: pulumi.Output[str]
    """
    Name of the Network Zone Resource.
    """
    proxies: pulumi.Output[list]
    """
    Array of values in CIDR/range form.
    """
    type: pulumi.Output[str]
    """
    Type of the Network Zone - can either be IP or DYNAMIC only.
    """
    def __init__(__self__, resource_name, opts=None, dynamic_locations=None, gateways=None, name=None, proxies=None, type=None, __props__=None, __name__=None, __opts__=None):
        """
        Creates an Okta Network Zone.

        This resource allows you to create and configure an Okta Network Zone.

        ## Example Usage



        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.network.Zone("example",
            gateways=[
                "1.2.3.4/24",
                "2.3.4.5-2.3.4.15",
            ],
            proxies=[
                "2.2.3.4/24",
                "3.3.4.5-3.3.4.15",
            ],
            type="IP")
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] dynamic_locations: Array of locations ISO-3166-1(2). Format code: countryCode OR countryCode-regionCode.
        :param pulumi.Input[list] gateways: Array of values in CIDR/range form.
        :param pulumi.Input[str] name: Name of the Network Zone Resource.
        :param pulumi.Input[list] proxies: Array of values in CIDR/range form.
        :param pulumi.Input[str] type: Type of the Network Zone - can either be IP or DYNAMIC only.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['dynamic_locations'] = dynamic_locations
            __props__['gateways'] = gateways
            __props__['name'] = name
            __props__['proxies'] = proxies
            if type is None:
                raise TypeError("Missing required property 'type'")
            __props__['type'] = type
        super(Zone, __self__).__init__(
            'okta:network/zone:Zone',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, dynamic_locations=None, gateways=None, name=None, proxies=None, type=None):
        """
        Get an existing Zone resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] dynamic_locations: Array of locations ISO-3166-1(2). Format code: countryCode OR countryCode-regionCode.
        :param pulumi.Input[list] gateways: Array of values in CIDR/range form.
        :param pulumi.Input[str] name: Name of the Network Zone Resource.
        :param pulumi.Input[list] proxies: Array of values in CIDR/range form.
        :param pulumi.Input[str] type: Type of the Network Zone - can either be IP or DYNAMIC only.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["dynamic_locations"] = dynamic_locations
        __props__["gateways"] = gateways
        __props__["name"] = name
        __props__["proxies"] = proxies
        __props__["type"] = type
        return Zone(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class Mfa(pulumi.CustomResource):
    description: pulumi.Output[str]
    """
    Policy Description.
    """
    duo: pulumi.Output[dict]
    """
    DUO MFA policy settings.

      * `consent_type` (`str`) - User consent type required before enrolling in the factor: `"NONE"` or `"TERMS_OF_SERVICE"`. By default it is `"NONE"`.
      * `enroll` (`str`) - Requirements for user initiated enrollment. Can be `"NOT_ALLOWED"`, `"OPTIONAL"`, or `"REQUIRED"`. By default it is `"OPTIONAL"`.
    """
    fido_u2f: pulumi.Output[dict]
    """
    Fido U2F MFA policy settings.

      * `consent_type` (`str`) - User consent type required before enrolling in the factor: `"NONE"` or `"TERMS_OF_SERVICE"`. By default it is `"NONE"`.
      * `enroll` (`str`) - Requirements for user initiated enrollment. Can be `"NOT_ALLOWED"`, `"OPTIONAL"`, or `"REQUIRED"`. By default it is `"OPTIONAL"`.
    """
    fido_webauthn: pulumi.Output[dict]
    """
    Fido Web Authn MFA policy settings.

      * `consent_type` (`str`) - User consent type required before enrolling in the factor: `"NONE"` or `"TERMS_OF_SERVICE"`. By default it is `"NONE"`.
      * `enroll` (`str`) - Requirements for user initiated enrollment. Can be `"NOT_ALLOWED"`, `"OPTIONAL"`, or `"REQUIRED"`. By default it is `"OPTIONAL"`.
    """
    google_otp: pulumi.Output[dict]
    """
    Google OTP MFA policy settings.

      * `consent_type` (`str`) - User consent type required before enrolling in the factor: `"NONE"` or `"TERMS_OF_SERVICE"`. By default it is `"NONE"`.
      * `enroll` (`str`) - Requirements for user initiated enrollment. Can be `"NOT_ALLOWED"`, `"OPTIONAL"`, or `"REQUIRED"`. By default it is `"OPTIONAL"`.
    """
    groups_includeds: pulumi.Output[list]
    """
    List of Group IDs to Include.
    """
    name: pulumi.Output[str]
    """
    Policy Name.
    """
    okta_call: pulumi.Output[dict]
    """
    Okta Call MFA policy settings.

      * `consent_type` (`str`) - User consent type required before enrolling in the factor: `"NONE"` or `"TERMS_OF_SERVICE"`. By default it is `"NONE"`.
      * `enroll` (`str`) - Requirements for user initiated enrollment. Can be `"NOT_ALLOWED"`, `"OPTIONAL"`, or `"REQUIRED"`. By default it is `"OPTIONAL"`.
    """
    okta_otp: pulumi.Output[dict]
    """
    Okta OTP MFA policy settings.

      * `consent_type` (`str`) - User consent type required before enrolling in the factor: `"NONE"` or `"TERMS_OF_SERVICE"`. By default it is `"NONE"`.
      * `enroll` (`str`) - Requirements for user initiated enrollment. Can be `"NOT_ALLOWED"`, `"OPTIONAL"`, or `"REQUIRED"`. By default it is `"OPTIONAL"`.
    """
    okta_password: pulumi.Output[dict]
    """
    Okta Password MFA policy settings.

      * `consent_type` (`str`) - User consent type required before enrolling in the factor: `"NONE"` or `"TERMS_OF_SERVICE"`. By default it is `"NONE"`.
      * `enroll` (`str`) - Requirements for user initiated enrollment. Can be `"NOT_ALLOWED"`, `"OPTIONAL"`, or `"REQUIRED"`. By default it is `"OPTIONAL"`.
    """
    okta_push: pulumi.Output[dict]
    """
    Okta Push MFA policy settings.

      * `consent_type` (`str`) - User consent type required before enrolling in the factor: `"NONE"` or `"TERMS_OF_SERVICE"`. By default it is `"NONE"`.
      * `enroll` (`str`) - Requirements for user initiated enrollment. Can be `"NOT_ALLOWED"`, `"OPTIONAL"`, or `"REQUIRED"`. By default it is `"OPTIONAL"`.
    """
    okta_question: pulumi.Output[dict]
    """
    Okta Question MFA policy settings.

      * `consent_type` (`str`) - User consent type required before enrolling in the factor: `"NONE"` or `"TERMS_OF_SERVICE"`. By default it is `"NONE"`.
      * `enroll` (`str`) - Requirements for user initiated enrollment. Can be `"NOT_ALLOWED"`, `"OPTIONAL"`, or `"REQUIRED"`. By default it is `"OPTIONAL"`.
    """
    okta_sms: pulumi.Output[dict]
    """
    Okta SMS MFA policy settings.

      * `consent_type` (`str`) - User consent type required before enrolling in the factor: `"NONE"` or `"TERMS_OF_SERVICE"`. By default it is `"NONE"`.
      * `enroll` (`str`) - Requirements for user initiated enrollment. Can be `"NOT_ALLOWED"`, `"OPTIONAL"`, or `"REQUIRED"`. By default it is `"OPTIONAL"`.
    """
    priority: pulumi.Output[float]
    """
    Priority of the policy.
    """
    rsa_token: pulumi.Output[dict]
    """
    RSA Token MFA policy settings.

      * `consent_type` (`str`) - User consent type required before enrolling in the factor: `"NONE"` or `"TERMS_OF_SERVICE"`. By default it is `"NONE"`.
      * `enroll` (`str`) - Requirements for user initiated enrollment. Can be `"NOT_ALLOWED"`, `"OPTIONAL"`, or `"REQUIRED"`. By default it is `"OPTIONAL"`.
    """
    status: pulumi.Output[str]
    """
    Policy Status: `"ACTIVE"` or `"INACTIVE"`.
    """
    symantec_vip: pulumi.Output[dict]
    """
    Symantec VIP MFA policy settings.

      * `consent_type` (`str`) - User consent type required before enrolling in the factor: `"NONE"` or `"TERMS_OF_SERVICE"`. By default it is `"NONE"`.
      * `enroll` (`str`) - Requirements for user initiated enrollment. Can be `"NOT_ALLOWED"`, `"OPTIONAL"`, or `"REQUIRED"`. By default it is `"OPTIONAL"`.
    """
    yubikey_token: pulumi.Output[dict]
    """
    Yubikey Token MFA policy settings.

      * `consent_type` (`str`) - User consent type required before enrolling in the factor: `"NONE"` or `"TERMS_OF_SERVICE"`. By default it is `"NONE"`.
      * `enroll` (`str`) - Requirements for user initiated enrollment. Can be `"NOT_ALLOWED"`, `"OPTIONAL"`, or `"REQUIRED"`. By default it is `"OPTIONAL"`.
    """
    def __init__(__self__, resource_name, opts=None, description=None, duo=None, fido_u2f=None, fido_webauthn=None, google_otp=None, groups_includeds=None, name=None, okta_call=None, okta_otp=None, okta_password=None, okta_push=None, okta_question=None, okta_sms=None, priority=None, rsa_token=None, status=None, symantec_vip=None, yubikey_token=None, __props__=None, __name__=None, __opts__=None):
        """
        Creates an MFA Policy.

        This resource allows you to create and configure an MFA Policy.

        ## Example Usage



        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.policy.Mfa("example",
            description="Example",
            groups_includeds=[data["group.Group"]["everyone"]["id"]],
            okta_otp={
                "enroll": "REQUIRED",
            },
            status="ACTIVE")
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: Policy Description.
        :param pulumi.Input[dict] duo: DUO MFA policy settings.
        :param pulumi.Input[dict] fido_u2f: Fido U2F MFA policy settings.
        :param pulumi.Input[dict] fido_webauthn: Fido Web Authn MFA policy settings.
        :param pulumi.Input[dict] google_otp: Google OTP MFA policy settings.
        :param pulumi.Input[list] groups_includeds: List of Group IDs to Include.
        :param pulumi.Input[str] name: Policy Name.
        :param pulumi.Input[dict] okta_call: Okta Call MFA policy settings.
        :param pulumi.Input[dict] okta_otp: Okta OTP MFA policy settings.
        :param pulumi.Input[dict] okta_password: Okta Password MFA policy settings.
        :param pulumi.Input[dict] okta_push: Okta Push MFA policy settings.
        :param pulumi.Input[dict] okta_question: Okta Question MFA policy settings.
        :param pulumi.Input[dict] okta_sms: Okta SMS MFA policy settings.
        :param pulumi.Input[float] priority: Priority of the policy.
        :param pulumi.Input[dict] rsa_token: RSA Token MFA policy settings.
        :param pulumi.Input[str] status: Policy Status: `"ACTIVE"` or `"INACTIVE"`.
        :param pulumi.Input[dict] symantec_vip: Symantec VIP MFA policy settings.
        :param pulumi.Input[dict] yubikey_token: Yubikey Token MFA policy settings.

        The **duo** object supports the following:

          * `consent_type` (`pulumi.Input[str]`) - User consent type required before enrolling in the factor: `"NONE"` or `"TERMS_OF_SERVICE"`. By default it is `"NONE"`.
          * `enroll` (`pulumi.Input[str]`) - Requirements for user initiated enrollment. Can be `"NOT_ALLOWED"`, `"OPTIONAL"`, or `"REQUIRED"`. By default it is `"OPTIONAL"`.

        The **fido_u2f** object supports the following:

          * `consent_type` (`pulumi.Input[str]`) - User consent type required before enrolling in the factor: `"NONE"` or `"TERMS_OF_SERVICE"`. By default it is `"NONE"`.
          * `enroll` (`pulumi.Input[str]`) - Requirements for user initiated enrollment. Can be `"NOT_ALLOWED"`, `"OPTIONAL"`, or `"REQUIRED"`. By default it is `"OPTIONAL"`.

        The **fido_webauthn** object supports the following:

          * `consent_type` (`pulumi.Input[str]`) - User consent type required before enrolling in the factor: `"NONE"` or `"TERMS_OF_SERVICE"`. By default it is `"NONE"`.
          * `enroll` (`pulumi.Input[str]`) - Requirements for user initiated enrollment. Can be `"NOT_ALLOWED"`, `"OPTIONAL"`, or `"REQUIRED"`. By default it is `"OPTIONAL"`.

        The **google_otp** object supports the following:

          * `consent_type` (`pulumi.Input[str]`) - User consent type required before enrolling in the factor: `"NONE"` or `"TERMS_OF_SERVICE"`. By default it is `"NONE"`.
          * `enroll` (`pulumi.Input[str]`) - Requirements for user initiated enrollment. Can be `"NOT_ALLOWED"`, `"OPTIONAL"`, or `"REQUIRED"`. By default it is `"OPTIONAL"`.

        The **okta_call** object supports the following:

          * `consent_type` (`pulumi.Input[str]`) - User consent type required before enrolling in the factor: `"NONE"` or `"TERMS_OF_SERVICE"`. By default it is `"NONE"`.
          * `enroll` (`pulumi.Input[str]`) - Requirements for user initiated enrollment. Can be `"NOT_ALLOWED"`, `"OPTIONAL"`, or `"REQUIRED"`. By default it is `"OPTIONAL"`.

        The **okta_otp** object supports the following:

          * `consent_type` (`pulumi.Input[str]`) - User consent type required before enrolling in the factor: `"NONE"` or `"TERMS_OF_SERVICE"`. By default it is `"NONE"`.
          * `enroll` (`pulumi.Input[str]`) - Requirements for user initiated enrollment. Can be `"NOT_ALLOWED"`, `"OPTIONAL"`, or `"REQUIRED"`. By default it is `"OPTIONAL"`.

        The **okta_password** object supports the following:

          * `consent_type` (`pulumi.Input[str]`) - User consent type required before enrolling in the factor: `"NONE"` or `"TERMS_OF_SERVICE"`. By default it is `"NONE"`.
          * `enroll` (`pulumi.Input[str]`) - Requirements for user initiated enrollment. Can be `"NOT_ALLOWED"`, `"OPTIONAL"`, or `"REQUIRED"`. By default it is `"OPTIONAL"`.

        The **okta_push** object supports the following:

          * `consent_type` (`pulumi.Input[str]`) - User consent type required before enrolling in the factor: `"NONE"` or `"TERMS_OF_SERVICE"`. By default it is `"NONE"`.
          * `enroll` (`pulumi.Input[str]`) - Requirements for user initiated enrollment. Can be `"NOT_ALLOWED"`, `"OPTIONAL"`, or `"REQUIRED"`. By default it is `"OPTIONAL"`.

        The **okta_question** object supports the following:

          * `consent_type` (`pulumi.Input[str]`) - User consent type required before enrolling in the factor: `"NONE"` or `"TERMS_OF_SERVICE"`. By default it is `"NONE"`.
          * `enroll` (`pulumi.Input[str]`) - Requirements for user initiated enrollment. Can be `"NOT_ALLOWED"`, `"OPTIONAL"`, or `"REQUIRED"`. By default it is `"OPTIONAL"`.

        The **okta_sms** object supports the following:

          * `consent_type` (`pulumi.Input[str]`) - User consent type required before enrolling in the factor: `"NONE"` or `"TERMS_OF_SERVICE"`. By default it is `"NONE"`.
          * `enroll` (`pulumi.Input[str]`) - Requirements for user initiated enrollment. Can be `"NOT_ALLOWED"`, `"OPTIONAL"`, or `"REQUIRED"`. By default it is `"OPTIONAL"`.

        The **rsa_token** object supports the following:

          * `consent_type` (`pulumi.Input[str]`) - User consent type required before enrolling in the factor: `"NONE"` or `"TERMS_OF_SERVICE"`. By default it is `"NONE"`.
          * `enroll` (`pulumi.Input[str]`) - Requirements for user initiated enrollment. Can be `"NOT_ALLOWED"`, `"OPTIONAL"`, or `"REQUIRED"`. By default it is `"OPTIONAL"`.

        The **symantec_vip** object supports the following:

          * `consent_type` (`pulumi.Input[str]`) - User consent type required before enrolling in the factor: `"NONE"` or `"TERMS_OF_SERVICE"`. By default it is `"NONE"`.
          * `enroll` (`pulumi.Input[str]`) - Requirements for user initiated enrollment. Can be `"NOT_ALLOWED"`, `"OPTIONAL"`, or `"REQUIRED"`. By default it is `"OPTIONAL"`.

        The **yubikey_token** object supports the following:

          * `consent_type` (`pulumi.Input[str]`) - User consent type required before enrolling in the factor: `"NONE"` or `"TERMS_OF_SERVICE"`. By default it is `"NONE"`.
          * `enroll` (`pulumi.Input[str]`) - Requirements for user initiated enrollment. Can be `"NOT_ALLOWED"`, `"OPTIONAL"`, or `"REQUIRED"`. By default it is `"OPTIONAL"`.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['description'] = description
            __props__['duo'] = duo
            __props__['fido_u2f'] = fido_u2f
            __props__['fido_webauthn'] = fido_webauthn
            __props__['google_otp'] = google_otp
            __props__['groups_includeds'] = groups_includeds
            __props__['name'] = name
            __props__['okta_call'] = okta_call
            __props__['okta_otp'] = okta_otp
            __props__['okta_password'] = okta_password
            __props__['okta_push'] = okta_push
            __props__['okta_question'] = okta_question
            __props__['okta_sms'] = okta_sms
            __props__['priority'] = priority
            __props__['rsa_token'] = rsa_token
            __props__['status'] = status
            __props__['symantec_vip'] = symantec_vip
            __props__['yubikey_token'] = yubikey_token
        super(Mfa, __self__).__init__(
            'okta:policy/mfa:Mfa',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, description=None, duo=None, fido_u2f=None, fido_webauthn=None, google_otp=None, groups_includeds=None, name=None, okta_call=None, okta_otp=None, okta_password=None, okta_push=None, okta_question=None, okta_sms=None, priority=None, rsa_token=None, status=None, symantec_vip=None, yubikey_token=None):
        """
        Get an existing Mfa resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: Policy Description.
        :param pulumi.Input[dict] duo: DUO MFA policy settings.
        :param pulumi.Input[dict] fido_u2f: Fido U2F MFA policy settings.
        :param pulumi.Input[dict] fido_webauthn: Fido Web Authn MFA policy settings.
        :param pulumi.Input[dict] google_otp: Google OTP MFA policy settings.
        :param pulumi.Input[list] groups_includeds: List of Group IDs to Include.
        :param pulumi.Input[str] name: Policy Name.
        :param pulumi.Input[dict] okta_call: Okta Call MFA policy settings.
        :param pulumi.Input[dict] okta_otp: Okta OTP MFA policy settings.
        :param pulumi.Input[dict] okta_password: Okta Password MFA policy settings.
        :param pulumi.Input[dict] okta_push: Okta Push MFA policy settings.
        :param pulumi.Input[dict] okta_question: Okta Question MFA policy settings.
        :param pulumi.Input[dict] okta_sms: Okta SMS MFA policy settings.
        :param pulumi.Input[float] priority: Priority of the policy.
        :param pulumi.Input[dict] rsa_token: RSA Token MFA policy settings.
        :param pulumi.Input[str] status: Policy Status: `"ACTIVE"` or `"INACTIVE"`.
        :param pulumi.Input[dict] symantec_vip: Symantec VIP MFA policy settings.
        :param pulumi.Input[dict] yubikey_token: Yubikey Token MFA policy settings.

        The **duo** object supports the following:

          * `consent_type` (`pulumi.Input[str]`) - User consent type required before enrolling in the factor: `"NONE"` or `"TERMS_OF_SERVICE"`. By default it is `"NONE"`.
          * `enroll` (`pulumi.Input[str]`) - Requirements for user initiated enrollment. Can be `"NOT_ALLOWED"`, `"OPTIONAL"`, or `"REQUIRED"`. By default it is `"OPTIONAL"`.

        The **fido_u2f** object supports the following:

          * `consent_type` (`pulumi.Input[str]`) - User consent type required before enrolling in the factor: `"NONE"` or `"TERMS_OF_SERVICE"`. By default it is `"NONE"`.
          * `enroll` (`pulumi.Input[str]`) - Requirements for user initiated enrollment. Can be `"NOT_ALLOWED"`, `"OPTIONAL"`, or `"REQUIRED"`. By default it is `"OPTIONAL"`.

        The **fido_webauthn** object supports the following:

          * `consent_type` (`pulumi.Input[str]`) - User consent type required before enrolling in the factor: `"NONE"` or `"TERMS_OF_SERVICE"`. By default it is `"NONE"`.
          * `enroll` (`pulumi.Input[str]`) - Requirements for user initiated enrollment. Can be `"NOT_ALLOWED"`, `"OPTIONAL"`, or `"REQUIRED"`. By default it is `"OPTIONAL"`.

        The **google_otp** object supports the following:

          * `consent_type` (`pulumi.Input[str]`) - User consent type required before enrolling in the factor: `"NONE"` or `"TERMS_OF_SERVICE"`. By default it is `"NONE"`.
          * `enroll` (`pulumi.Input[str]`) - Requirements for user initiated enrollment. Can be `"NOT_ALLOWED"`, `"OPTIONAL"`, or `"REQUIRED"`. By default it is `"OPTIONAL"`.

        The **okta_call** object supports the following:

          * `consent_type` (`pulumi.Input[str]`) - User consent type required before enrolling in the factor: `"NONE"` or `"TERMS_OF_SERVICE"`. By default it is `"NONE"`.
          * `enroll` (`pulumi.Input[str]`) - Requirements for user initiated enrollment. Can be `"NOT_ALLOWED"`, `"OPTIONAL"`, or `"REQUIRED"`. By default it is `"OPTIONAL"`.

        The **okta_otp** object supports the following:

          * `consent_type` (`pulumi.Input[str]`) - User consent type required before enrolling in the factor: `"NONE"` or `"TERMS_OF_SERVICE"`. By default it is `"NONE"`.
          * `enroll` (`pulumi.Input[str]`) - Requirements for user initiated enrollment. Can be `"NOT_ALLOWED"`, `"OPTIONAL"`, or `"REQUIRED"`. By default it is `"OPTIONAL"`.

        The **okta_password** object supports the following:

          * `consent_type` (`pulumi.Input[str]`) - User consent type required before enrolling in the factor: `"NONE"` or `"TERMS_OF_SERVICE"`. By default it is `"NONE"`.
          * `enroll` (`pulumi.Input[str]`) - Requirements for user initiated enrollment. Can be `"NOT_ALLOWED"`, `"OPTIONAL"`, or `"REQUIRED"`. By default it is `"OPTIONAL"`.

        The **okta_push** object supports the following:

          * `consent_type` (`pulumi.Input[str]`) - User consent type required before enrolling in the factor: `"NONE"` or `"TERMS_OF_SERVICE"`. By default it is `"NONE"`.
          * `enroll` (`pulumi.Input[str]`) - Requirements for user initiated enrollment. Can be `"NOT_ALLOWED"`, `"OPTIONAL"`, or `"REQUIRED"`. By default it is `"OPTIONAL"`.

        The **okta_question** object supports the following:

          * `consent_type` (`pulumi.Input[str]`) - User consent type required before enrolling in the factor: `"NONE"` or `"TERMS_OF_SERVICE"`. By default it is `"NONE"`.
          * `enroll` (`pulumi.Input[str]`) - Requirements for user initiated enrollment. Can be `"NOT_ALLOWED"`, `"OPTIONAL"`, or `"REQUIRED"`. By default it is `"OPTIONAL"`.

        The **okta_sms** object supports the following:

          * `consent_type` (`pulumi.Input[str]`) - User consent type required before enrolling in the factor: `"NONE"` or `"TERMS_OF_SERVICE"`. By default it is `"NONE"`.
          * `enroll` (`pulumi.Input[str]`) - Requirements for user initiated enrollment. Can be `"NOT_ALLOWED"`, `"OPTIONAL"`, or `"REQUIRED"`. By default it is `"OPTIONAL"`.

        The **rsa_token** object supports the following:

          * `consent_type` (`pulumi.Input[str]`) - User consent type required before enrolling in the factor: `"NONE"` or `"TERMS_OF_SERVICE"`. By default it is `"NONE"`.
          * `enroll` (`pulumi.Input[str]`) - Requirements for user initiated enrollment. Can be `"NOT_ALLOWED"`, `"OPTIONAL"`, or `"REQUIRED"`. By default it is `"OPTIONAL"`.

        The **symantec_vip** object supports the following:

          * `consent_type` (`pulumi.Input[str]`) - User consent type required before enrolling in the factor: `"NONE"` or `"TERMS_OF_SERVICE"`. By default it is `"NONE"`.
          * `enroll` (`pulumi.Input[str]`) - Requirements for user initiated enrollment. Can be `"NOT_ALLOWED"`, `"OPTIONAL"`, or `"REQUIRED"`. By default it is `"OPTIONAL"`.

        The **yubikey_token** object supports the following:

          * `consent_type` (`pulumi.Input[str]`) - User consent type required before enrolling in the factor: `"NONE"` or `"TERMS_OF_SERVICE"`. By default it is `"NONE"`.
          * `enroll` (`pulumi.Input[str]`) - Requirements for user initiated enrollment. Can be `"NOT_ALLOWED"`, `"OPTIONAL"`, or `"REQUIRED"`. By default it is `"OPTIONAL"`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["description"] = description
        __props__["duo"] = duo
        __props__["fido_u2f"] = fido_u2f
        __props__["fido_webauthn"] = fido_webauthn
        __props__["google_otp"] = google_otp
        __props__["groups_includeds"] = groups_includeds
        __props__["name"] = name
        __props__["okta_call"] = okta_call
        __props__["okta_otp"] = okta_otp
        __props__["okta_password"] = okta_password
        __props__["okta_push"] = okta_push
        __props__["okta_question"] = okta_question
        __props__["okta_sms"] = okta_sms
        __props__["priority"] = priority
        __props__["rsa_token"] = rsa_token
        __props__["status"] = status
        __props__["symantec_vip"] = symantec_vip
        __props__["yubikey_token"] = yubikey_token
        return Mfa(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class Saml(pulumi.CustomResource):
    account_link_action: pulumi.Output[str]
    """
    Specifies the account linking action for an IdP user.
    """
    account_link_group_includes: pulumi.Output[list]
    """
    Group memberships to determine link candidates.
    """
    acs_binding: pulumi.Output[str]
    """
    The method of making an ACS request. It can be set to `"HTTP-POST"` or `"HTTP-REDIRECT"`.
    """
    acs_type: pulumi.Output[str]
    """
    The type of ACS. It can be `"INSTANCE"` or `"ORG"`.
    """
    audience: pulumi.Output[str]
    """
    The audience restriction for the IdP.
    """
    deprovisioned_action: pulumi.Output[str]
    """
    Action for a previously deprovisioned IdP user during authentication. Can be `"NONE"` or `"REACTIVATE"`.
    """
    groups_action: pulumi.Output[str]
    """
    Provisioning action for IdP user's group memberships. It can be `"NONE"`, `"SYNC"`, `"APPEND"`, or `"ASSIGN"`.
    """
    groups_assignments: pulumi.Output[list]
    """
    List of Okta Group IDs to add an IdP user as a member with the `"ASSIGN"` `groups_action`.
    """
    groups_attribute: pulumi.Output[str]
    """
    IdP user profile attribute name (case-insensitive) for an array value that contains group memberships.
    """
    groups_filters: pulumi.Output[list]
    """
    Whitelist of Okta Group identifiers that are allowed for the `"APPEND"` or `"SYNC"` `groups_action`.
    """
    issuer: pulumi.Output[str]
    """
    URI that identifies the issuer.
    """
    issuer_mode: pulumi.Output[str]
    """
    Indicates whether Okta uses the original Okta org domain URL, or a custom domain URL. It can be `"ORG_URL"` or `"CUSTOM_URL"`.
    """
    kid: pulumi.Output[str]
    """
    The ID of the signing key.
    """
    name: pulumi.Output[str]
    """
    The Application's display name.
    """
    name_format: pulumi.Output[str]
    """
    The name identifier format to use. By default `"urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"`.
    """
    profile_master: pulumi.Output[bool]
    """
    Determines if the IdP should act as a source of truth for user profile attributes.
    """
    provisioning_action: pulumi.Output[str]
    """
    Provisioning action for an IdP user during authentication.
    """
    request_signature_algorithm: pulumi.Output[str]
    """
    The XML digital signature algorithm used when signing an AuthnRequest message.
    """
    request_signature_scope: pulumi.Output[str]
    """
    Specifies whether or not to digitally sign an AuthnRequest messages to the IdP. It can be `"REQUEST"` or `"NONE"`.
    """
    response_signature_algorithm: pulumi.Output[str]
    """
    The minimum XML digital signature algorithm allowed when verifying a SAMLResponse message or Assertion element.
    """
    response_signature_scope: pulumi.Output[str]
    """
    Specifies whether to verify a SAMLResponse message or Assertion element XML digital signature. It can be `"RESPONSE"`, `"ASSERTION"`, or `"ANY"`.
    """
    sso_binding: pulumi.Output[str]
    """
    The method of making an SSO request. It can be set to `"HTTP-POST"` or `"HTTP-REDIRECT"`.
    """
    sso_destination: pulumi.Output[str]
    """
    URI reference indicating the address to which the AuthnRequest message is sent.
    """
    sso_url: pulumi.Output[str]
    """
    URL of binding-specific endpoint to send an AuthnRequest message to IdP.
    """
    status: pulumi.Output[str]
    """
    Status of the IdP.
    """
    subject_filter: pulumi.Output[str]
    """
    Optional regular expression pattern used to filter untrusted IdP usernames.
    """
    subject_formats: pulumi.Output[list]
    """
    The name formate. By default `"urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"`.
    """
    subject_match_attribute: pulumi.Output[str]
    """
    Okta user profile attribute for matching transformed IdP username. Only for matchType `"CUSTOM_ATTRIBUTE"`.
    """
    subject_match_type: pulumi.Output[str]
    """
    Determines the Okta user profile attribute match conditions for account linking and authentication of the transformed IdP username. By default it is set to `"USERNAME"`. It can be set to `"USERNAME"`, `"EMAIL"`, `"USERNAME_OR_EMAIL"` or `"CUSTOM_ATTRIBUTE"`.
    """
    suspended_action: pulumi.Output[str]
    """
    Action for a previously suspended IdP user during authentication. Can be set to `"NONE"` or `"UNSUSPEND"`
    """
    type: pulumi.Output[str]
    """
    Type of the IdP.
    """
    username_template: pulumi.Output[str]
    """
    Okta EL Expression to generate or transform a unique username for the IdP user.
    """
    def __init__(__self__, resource_name, opts=None, account_link_action=None, account_link_group_includes=None, acs_binding=None, acs_type=None, deprovisioned_action=None, groups_action=None, groups_assignments=None, groups_attribute=None, groups_filters=None, issuer=None, issuer_mode=None, kid=None, name=None, name_format=None, profile_master=None, provisioning_action=None, request_signature_algorithm=None, request_signature_scope=None, response_signature_algorithm=None, response_signature_scope=None, sso_binding=None, sso_destination=None, sso_url=None, status=None, subject_filter=None, subject_formats=None, subject_match_attribute=None, subject_match_type=None, suspended_action=None, username_template=None, __props__=None, __name__=None, __opts__=None):
        """
        Creates a SAML Identity Provider.

        This resource allows you to create and configure a SAML Identity Provider.

        ## Example Usage



        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.idp.Saml("example",
            acs_binding="HTTP-POST",
            acs_type="INSTANCE",
            issuer="https://idp.example.com",
            kid=okta_idp_saml_key["test"]["id"],
            request_signature_scope="REQUEST",
            response_signature_scope="ANY",
            sso_binding="HTTP-POST",
            sso_destination="https://idp.example.com",
            sso_url="https://idp.example.com",
            username_template="idpuser.email")
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] account_link_action: Specifies the account linking action for an IdP user.
        :param pulumi.Input[list] account_link_group_includes: Group memberships to determine link candidates.
        :param pulumi.Input[str] acs_binding: The method of making an ACS request. It can be set to `"HTTP-POST"` or `"HTTP-REDIRECT"`.
        :param pulumi.Input[str] acs_type: The type of ACS. It can be `"INSTANCE"` or `"ORG"`.
        :param pulumi.Input[str] deprovisioned_action: Action for a previously deprovisioned IdP user during authentication. Can be `"NONE"` or `"REACTIVATE"`.
        :param pulumi.Input[str] groups_action: Provisioning action for IdP user's group memberships. It can be `"NONE"`, `"SYNC"`, `"APPEND"`, or `"ASSIGN"`.
        :param pulumi.Input[list] groups_assignments: List of Okta Group IDs to add an IdP user as a member with the `"ASSIGN"` `groups_action`.
        :param pulumi.Input[str] groups_attribute: IdP user profile attribute name (case-insensitive) for an array value that contains group memberships.
        :param pulumi.Input[list] groups_filters: Whitelist of Okta Group identifiers that are allowed for the `"APPEND"` or `"SYNC"` `groups_action`.
        :param pulumi.Input[str] issuer: URI that identifies the issuer.
        :param pulumi.Input[str] issuer_mode: Indicates whether Okta uses the original Okta org domain URL, or a custom domain URL. It can be `"ORG_URL"` or `"CUSTOM_URL"`.
        :param pulumi.Input[str] kid: The ID of the signing key.
        :param pulumi.Input[str] name: The Application's display name.
        :param pulumi.Input[str] name_format: The name identifier format to use. By default `"urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"`.
        :param pulumi.Input[bool] profile_master: Determines if the IdP should act as a source of truth for user profile attributes.
        :param pulumi.Input[str] provisioning_action: Provisioning action for an IdP user during authentication.
        :param pulumi.Input[str] request_signature_algorithm: The XML digital signature algorithm used when signing an AuthnRequest message.
        :param pulumi.Input[str] request_signature_scope: Specifies whether or not to digitally sign an AuthnRequest messages to the IdP. It can be `"REQUEST"` or `"NONE"`.
        :param pulumi.Input[str] response_signature_algorithm: The minimum XML digital signature algorithm allowed when verifying a SAMLResponse message or Assertion element.
        :param pulumi.Input[str] response_signature_scope: Specifies whether to verify a SAMLResponse message or Assertion element XML digital signature. It can be `"RESPONSE"`, `"ASSERTION"`, or `"ANY"`.
        :param pulumi.Input[str] sso_binding: The method of making an SSO request. It can be set to `"HTTP-POST"` or `"HTTP-REDIRECT"`.
        :param pulumi.Input[str] sso_destination: URI reference indicating the address to which the AuthnRequest message is sent.
        :param pulumi.Input[str] sso_url: URL of binding-specific endpoint to send an AuthnRequest message to IdP.
        :param pulumi.Input[str] status: Status of the IdP.
        :param pulumi.Input[str] subject_filter: Optional regular expression pattern used to filter untrusted IdP usernames.
        :param pulumi.Input[list] subject_formats: The name formate. By default `"urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"`.
        :param pulumi.Input[str] subject_match_attribute: Okta user profile attribute for matching transformed IdP username. Only for matchType `"CUSTOM_ATTRIBUTE"`.
        :param pulumi.Input[str] subject_match_type: Determines the Okta user profile attribute match conditions for account linking and authentication of the transformed IdP username. By default it is set to `"USERNAME"`. It can be set to `"USERNAME"`, `"EMAIL"`, `"USERNAME_OR_EMAIL"` or `"CUSTOM_ATTRIBUTE"`.
        :param pulumi.Input[str] suspended_action: Action for a previously suspended IdP user during authentication. Can be set to `"NONE"` or `"UNSUSPEND"`
        :param pulumi.Input[str] username_template: Okta EL Expression to generate or transform a unique username for the IdP user.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['account_link_action'] = account_link_action
            __props__['account_link_group_includes'] = account_link_group_includes
            if acs_binding is None:
                raise TypeError("Missing required property 'acs_binding'")
            __props__['acs_binding'] = acs_binding
            __props__['acs_type'] = acs_type
            __props__['deprovisioned_action'] = deprovisioned_action
            __props__['groups_action'] = groups_action
            __props__['groups_assignments'] = groups_assignments
            __props__['groups_attribute'] = groups_attribute
            __props__['groups_filters'] = groups_filters
            if issuer is None:
                raise TypeError("Missing required property 'issuer'")
            __props__['issuer'] = issuer
            __props__['issuer_mode'] = issuer_mode
            if kid is None:
                raise TypeError("Missing required property 'kid'")
            __props__['kid'] = kid
            __props__['name'] = name
            __props__['name_format'] = name_format
            __props__['profile_master'] = profile_master
            __props__['provisioning_action'] = provisioning_action
            __props__['request_signature_algorithm'] = request_signature_algorithm
            __props__['request_signature_scope'] = request_signature_scope
            __props__['response_signature_algorithm'] = response_signature_algorithm
            __props__['response_signature_scope'] = response_signature_scope
            __props__['sso_binding'] = sso_binding
            __props__['sso_destination'] = sso_destination
            if sso_url is None:
                raise TypeError("Missing required property 'sso_url'")
            __props__['sso_url'] = sso_url
            __props__['status'] = status
            __props__['subject_filter'] = subject_filter
            __props__['subject_formats'] = subject_formats
            __props__['subject_match_attribute'] = subject_match_attribute
            __props__['subject_match_type'] = subject_match_type
            __props__['suspended_action'] = suspended_action
            __props__['username_template'] = username_template
            __props__['audience'] = None
            __props__['type'] = None
        super(Saml, __self__).__init__(
            'okta:idp/saml:Saml',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, account_link_action=None, account_link_group_includes=None, acs_binding=None, acs_type=None, audience=None, deprovisioned_action=None, groups_action=None, groups_assignments=None, groups_attribute=None, groups_filters=None, issuer=None, issuer_mode=None, kid=None, name=None, name_format=None, profile_master=None, provisioning_action=None, request_signature_algorithm=None, request_signature_scope=None, response_signature_algorithm=None, response_signature_scope=None, sso_binding=None, sso_destination=None, sso_url=None, status=None, subject_filter=None, subject_formats=None, subject_match_attribute=None, subject_match_type=None, suspended_action=None, type=None, username_template=None):
        """
        Get an existing Saml resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] account_link_action: Specifies the account linking action for an IdP user.
        :param pulumi.Input[list] account_link_group_includes: Group memberships to determine link candidates.
        :param pulumi.Input[str] acs_binding: The method of making an ACS request. It can be set to `"HTTP-POST"` or `"HTTP-REDIRECT"`.
        :param pulumi.Input[str] acs_type: The type of ACS. It can be `"INSTANCE"` or `"ORG"`.
        :param pulumi.Input[str] audience: The audience restriction for the IdP.
        :param pulumi.Input[str] deprovisioned_action: Action for a previously deprovisioned IdP user during authentication. Can be `"NONE"` or `"REACTIVATE"`.
        :param pulumi.Input[str] groups_action: Provisioning action for IdP user's group memberships. It can be `"NONE"`, `"SYNC"`, `"APPEND"`, or `"ASSIGN"`.
        :param pulumi.Input[list] groups_assignments: List of Okta Group IDs to add an IdP user as a member with the `"ASSIGN"` `groups_action`.
        :param pulumi.Input[str] groups_attribute: IdP user profile attribute name (case-insensitive) for an array value that contains group memberships.
        :param pulumi.Input[list] groups_filters: Whitelist of Okta Group identifiers that are allowed for the `"APPEND"` or `"SYNC"` `groups_action`.
        :param pulumi.Input[str] issuer: URI that identifies the issuer.
        :param pulumi.Input[str] issuer_mode: Indicates whether Okta uses the original Okta org domain URL, or a custom domain URL. It can be `"ORG_URL"` or `"CUSTOM_URL"`.
        :param pulumi.Input[str] kid: The ID of the signing key.
        :param pulumi.Input[str] name: The Application's display name.
        :param pulumi.Input[str] name_format: The name identifier format to use. By default `"urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"`.
        :param pulumi.Input[bool] profile_master: Determines if the IdP should act as a source of truth for user profile attributes.
        :param pulumi.Input[str] provisioning_action: Provisioning action for an IdP user during authentication.
        :param pulumi.Input[str] request_signature_algorithm: The XML digital signature algorithm used when signing an AuthnRequest message.
        :param pulumi.Input[str] request_signature_scope: Specifies whether or not to digitally sign an AuthnRequest messages to the IdP. It can be `"REQUEST"` or `"NONE"`.
        :param pulumi.Input[str] response_signature_algorithm: The minimum XML digital signature algorithm allowed when verifying a SAMLResponse message or Assertion element.
        :param pulumi.Input[str] response_signature_scope: Specifies whether to verify a SAMLResponse message or Assertion element XML digital signature. It can be `"RESPONSE"`, `"ASSERTION"`, or `"ANY"`.
        :param pulumi.Input[str] sso_binding: The method of making an SSO request. It can be set to `"HTTP-POST"` or `"HTTP-REDIRECT"`.
        :param pulumi.Input[str] sso_destination: URI reference indicating the address to which the AuthnRequest message is sent.
        :param pulumi.Input[str] sso_url: URL of binding-specific endpoint to send an AuthnRequest message to IdP.
        :param pulumi.Input[str] status: Status of the IdP.
        :param pulumi.Input[str] subject_filter: Optional regular expression pattern used to filter untrusted IdP usernames.
        :param pulumi.Input[list] subject_formats: The name formate. By default `"urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"`.
        :param pulumi.Input[str] subject_match_attribute: Okta user profile attribute for matching transformed IdP username. Only for matchType `"CUSTOM_ATTRIBUTE"`.
        :param pulumi.Input[str] subject_match_type: Determines the Okta user profile attribute match conditions for account linking and authentication of the transformed IdP username. By default it is set to `"USERNAME"`. It can be set to `"USERNAME"`, `"EMAIL"`, `"USERNAME_OR_EMAIL"` or `"CUSTOM_ATTRIBUTE"`.
        :param pulumi.Input[str] suspended_action: Action for a previously suspended IdP user during authentication. Can be set to `"NONE"` or `"UNSUSPEND"`
        :param pulumi.Input[str] type: Type of the IdP.
        :param pulumi.Input[str] username_template: Okta EL Expression to generate or transform a unique username for the IdP user.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["account_link_action"] = account_link_action
        __props__["account_link_group_includes"] = account_link_group_includes
        __props__["acs_binding"] = acs_binding
        __props__["acs_type"] = acs_type
        __props__["audience"] = audience
        __props__["deprovisioned_action"] = deprovisioned_action
        __props__["groups_action"] = groups_action
        __props__["groups_assignments"] = groups_assignments
        __props__["groups_attribute"] = groups_attribute
        __props__["groups_filters"] = groups_filters
        __props__["issuer"] = issuer
        __props__["issuer_mode"] = issuer_mode
        __props__["kid"] = kid
        __props__["name"] = name
        __props__["name_format"] = name_format
        __props__["profile_master"] = profile_master
        __props__["provisioning_action"] = provisioning_action
        __props__["request_signature_algorithm"] = request_signature_algorithm
        __props__["request_signature_scope"] = request_signature_scope
        __props__["response_signature_algorithm"] = response_signature_algorithm
        __props__["response_signature_scope"] = response_signature_scope
        __props__["sso_binding"] = sso_binding
        __props__["sso_destination"] = sso_destination
        __props__["sso_url"] = sso_url
        __props__["status"] = status
        __props__["subject_filter"] = subject_filter
        __props__["subject_formats"] = subject_formats
        __props__["subject_match_attribute"] = subject_match_attribute
        __props__["subject_match_type"] = subject_match_type
        __props__["suspended_action"] = suspended_action
        __props__["type"] = type
        __props__["username_template"] = username_template
        return Saml(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class OAuth(pulumi.CustomResource):
    auto_key_rotation: pulumi.Output[bool]
    """
    Requested key rotation mode.
    """
    auto_submit_toolbar: pulumi.Output[bool]
    """
    Display auto submit toolbar.
    """
    client_basic_secret: pulumi.Output[str]
    """
    OAuth client secret key, this can be set when token_endpoint_auth_method is client_secret_basic.
    """
    client_id: pulumi.Output[str]
    """
    The client ID of the application.
    """
    client_secret: pulumi.Output[str]
    """
    The client secret of the application.
    """
    client_uri: pulumi.Output[str]
    """
    URI to a web page providing information about the client.
    """
    consent_method: pulumi.Output[str]
    """
    Indicates whether user consent is required or implicit. Valid values: REQUIRED, TRUSTED. Default value is TRUSTED.
    """
    custom_client_id: pulumi.Output[str]
    """
    This property allows you to set the application's client id.
    """
    grant_types: pulumi.Output[list]
    """
    List of OAuth 2.0 grant types. Conditional validation params found here https://developer.okta.com/docs/api/resources/apps#credentials-settings-details. Defaults to minimum requirements per app type.
    """
    groups: pulumi.Output[list]
    """
    The groups assigned to the application. It is recommended not to use this and instead use `app.GroupAssignment`.
    """
    hide_ios: pulumi.Output[bool]
    """
    Do not display application icon on mobile app.
    """
    hide_web: pulumi.Output[bool]
    """
    Do not display application icon to users.
    """
    issuer_mode: pulumi.Output[str]
    """
    Indicates whether the Okta Authorization Server uses the original Okta org domain URL or a custom domain URL as the issuer of ID token for this client.
    """
    label: pulumi.Output[str]
    """
    The Application's display name.
    """
    login_uri: pulumi.Output[str]
    """
    URI that initiates login.
    """
    logo_uri: pulumi.Output[str]
    """
    URI that references a logo for the client.
    """
    name: pulumi.Output[str]
    """
    Name assigned to the application by Okta.
    """
    omit_secret: pulumi.Output[bool]
    """
    This tells the provider not to persist the application's secret to state. If this is ever changes from true => false your app will be recreated.
    """
    policy_uri: pulumi.Output[str]
    """
    URI to web page providing client policy document.
    """
    post_logout_redirect_uris: pulumi.Output[list]
    """
    List of URIs for redirection after logout.
    """
    profile: pulumi.Output[str]
    """
    Custom JSON that represents an OAuth application's profile.
    """
    redirect_uris: pulumi.Output[list]
    """
    List of URIs for use in the redirect-based flow. This is required for all application types except service.
    """
    response_types: pulumi.Output[list]
    """
    List of OAuth 2.0 response type strings.
    """
    sign_on_mode: pulumi.Output[str]
    """
    Sign on mode of application.
    """
    status: pulumi.Output[str]
    """
    The status of the application, by default it is `"ACTIVE"`.
    """
    token_endpoint_auth_method: pulumi.Output[str]
    """
    Requested authentication method for the token endpoint. It can be set to `"none"`, `"client_secret_post"`, `"client_secret_basic"`, `"client_secret_jwt"`.
    """
    tos_uri: pulumi.Output[str]
    """
    URI to web page providing client tos (terms of service).
    """
    type: pulumi.Output[str]
    """
    The type of OAuth application.
    """
    users: pulumi.Output[list]
    """
    The users assigned to the application. It is recommended not to use this and instead use `app.User`.

      * `id` (`str`)
      * `password` (`str`)
      * `scope` (`str`)
      * `username` (`str`)
    """
    def __init__(__self__, resource_name, opts=None, auto_key_rotation=None, auto_submit_toolbar=None, client_basic_secret=None, client_uri=None, consent_method=None, custom_client_id=None, grant_types=None, groups=None, hide_ios=None, hide_web=None, issuer_mode=None, label=None, login_uri=None, logo_uri=None, omit_secret=None, policy_uri=None, post_logout_redirect_uris=None, profile=None, redirect_uris=None, response_types=None, status=None, token_endpoint_auth_method=None, tos_uri=None, type=None, users=None, __props__=None, __name__=None, __opts__=None):
        """
        Creates an OIDC Application.

        This resource allows you to create and configure an OIDC Application.

        ## Example Usage



        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.app.OAuth("example",
            grant_types=["authorization_code"],
            label="example",
            redirect_uris=["https://example.com/"],
            response_types=["code"],
            type="web")
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] auto_key_rotation: Requested key rotation mode.
        :param pulumi.Input[bool] auto_submit_toolbar: Display auto submit toolbar.
        :param pulumi.Input[str] client_basic_secret: OAuth client secret key, this can be set when token_endpoint_auth_method is client_secret_basic.
        :param pulumi.Input[str] client_uri: URI to a web page providing information about the client.
        :param pulumi.Input[str] consent_method: Indicates whether user consent is required or implicit. Valid values: REQUIRED, TRUSTED. Default value is TRUSTED.
        :param pulumi.Input[str] custom_client_id: This property allows you to set the application's client id.
        :param pulumi.Input[list] grant_types: List of OAuth 2.0 grant types. Conditional validation params found here https://developer.okta.com/docs/api/resources/apps#credentials-settings-details. Defaults to minimum requirements per app type.
        :param pulumi.Input[list] groups: The groups assigned to the application. It is recommended not to use this and instead use `app.GroupAssignment`.
        :param pulumi.Input[bool] hide_ios: Do not display application icon on mobile app.
        :param pulumi.Input[bool] hide_web: Do not display application icon to users.
        :param pulumi.Input[str] issuer_mode: Indicates whether the Okta Authorization Server uses the original Okta org domain URL or a custom domain URL as the issuer of ID token for this client.
        :param pulumi.Input[str] label: The Application's display name.
        :param pulumi.Input[str] login_uri: URI that initiates login.
        :param pulumi.Input[str] logo_uri: URI that references a logo for the client.
        :param pulumi.Input[bool] omit_secret: This tells the provider not to persist the application's secret to state. If this is ever changes from true => false your app will be recreated.
        :param pulumi.Input[str] policy_uri: URI to web page providing client policy document.
        :param pulumi.Input[list] post_logout_redirect_uris: List of URIs for redirection after logout.
        :param pulumi.Input[str] profile: Custom JSON that represents an OAuth application's profile.
        :param pulumi.Input[list] redirect_uris: List of URIs for use in the redirect-based flow. This is required for all application types except service.
        :param pulumi.Input[list] response_types: List of OAuth 2.0 response type strings.
        :param pulumi.Input[str] status: The status of the application, by default it is `"ACTIVE"`.
        :param pulumi.Input[str] token_endpoint_auth_method: Requested authentication method for the token endpoint. It can be set to `"none"`, `"client_secret_post"`, `"client_secret_basic"`, `"client_secret_jwt"`.
        :param pulumi.Input[str] tos_uri: URI to web page providing client tos (terms of service).
        :param pulumi.Input[str] type: The type of OAuth application.
        :param pulumi.Input[list] users: The users assigned to the application. It is recommended not to use this and instead use `app.User`.

        The **users** object supports the following:

          * `id` (`pulumi.Input[str]`)
          * `password` (`pulumi.Input[str]`)
          * `scope` (`pulumi.Input[str]`)
          * `username` (`pulumi.Input[str]`)
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['auto_key_rotation'] = auto_key_rotation
            __props__['auto_submit_toolbar'] = auto_submit_toolbar
            __props__['client_basic_secret'] = client_basic_secret
            __props__['client_uri'] = client_uri
            __props__['consent_method'] = consent_method
            __props__['custom_client_id'] = custom_client_id
            __props__['grant_types'] = grant_types
            __props__['groups'] = groups
            __props__['hide_ios'] = hide_ios
            __props__['hide_web'] = hide_web
            __props__['issuer_mode'] = issuer_mode
            if label is None:
                raise TypeError("Missing required property 'label'")
            __props__['label'] = label
            __props__['login_uri'] = login_uri
            __props__['logo_uri'] = logo_uri
            __props__['omit_secret'] = omit_secret
            __props__['policy_uri'] = policy_uri
            __props__['post_logout_redirect_uris'] = post_logout_redirect_uris
            __props__['profile'] = profile
            __props__['redirect_uris'] = redirect_uris
            __props__['response_types'] = response_types
            __props__['status'] = status
            __props__['token_endpoint_auth_method'] = token_endpoint_auth_method
            __props__['tos_uri'] = tos_uri
            if type is None:
                raise TypeError("Missing required property 'type'")
            __props__['type'] = type
            __props__['users'] = users
            __props__['client_id'] = None
            __props__['client_secret'] = None
            __props__['name'] = None
            __props__['sign_on_mode'] = None
        super(OAuth, __self__).__init__(
            'okta:app/oAuth:OAuth',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, auto_key_rotation=None, auto_submit_toolbar=None, client_basic_secret=None, client_id=None, client_secret=None, client_uri=None, consent_method=None, custom_client_id=None, grant_types=None, groups=None, hide_ios=None, hide_web=None, issuer_mode=None, label=None, login_uri=None, logo_uri=None, name=None, omit_secret=None, policy_uri=None, post_logout_redirect_uris=None, profile=None, redirect_uris=None, response_types=None, sign_on_mode=None, status=None, token_endpoint_auth_method=None, tos_uri=None, type=None, users=None):
        """
        Get an existing OAuth resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] auto_key_rotation: Requested key rotation mode.
        :param pulumi.Input[bool] auto_submit_toolbar: Display auto submit toolbar.
        :param pulumi.Input[str] client_basic_secret: OAuth client secret key, this can be set when token_endpoint_auth_method is client_secret_basic.
        :param pulumi.Input[str] client_id: The client ID of the application.
        :param pulumi.Input[str] client_secret: The client secret of the application.
        :param pulumi.Input[str] client_uri: URI to a web page providing information about the client.
        :param pulumi.Input[str] consent_method: Indicates whether user consent is required or implicit. Valid values: REQUIRED, TRUSTED. Default value is TRUSTED.
        :param pulumi.Input[str] custom_client_id: This property allows you to set the application's client id.
        :param pulumi.Input[list] grant_types: List of OAuth 2.0 grant types. Conditional validation params found here https://developer.okta.com/docs/api/resources/apps#credentials-settings-details. Defaults to minimum requirements per app type.
        :param pulumi.Input[list] groups: The groups assigned to the application. It is recommended not to use this and instead use `app.GroupAssignment`.
        :param pulumi.Input[bool] hide_ios: Do not display application icon on mobile app.
        :param pulumi.Input[bool] hide_web: Do not display application icon to users.
        :param pulumi.Input[str] issuer_mode: Indicates whether the Okta Authorization Server uses the original Okta org domain URL or a custom domain URL as the issuer of ID token for this client.
        :param pulumi.Input[str] label: The Application's display name.
        :param pulumi.Input[str] login_uri: URI that initiates login.
        :param pulumi.Input[str] logo_uri: URI that references a logo for the client.
        :param pulumi.Input[str] name: Name assigned to the application by Okta.
        :param pulumi.Input[bool] omit_secret: This tells the provider not to persist the application's secret to state. If this is ever changes from true => false your app will be recreated.
        :param pulumi.Input[str] policy_uri: URI to web page providing client policy document.
        :param pulumi.Input[list] post_logout_redirect_uris: List of URIs for redirection after logout.
        :param pulumi.Input[str] profile: Custom JSON that represents an OAuth application's profile.
        :param pulumi.Input[list] redirect_uris: List of URIs for use in the redirect-based flow. This is required for all application types except service.
        :param pulumi.Input[list] response_types: List of OAuth 2.0 response type strings.
        :param pulumi.Input[str] sign_on_mode: Sign on mode of application.
        :param pulumi.Input[str] status: The status of the application, by default it is `"ACTIVE"`.
        :param pulumi.Input[str] token_endpoint_auth_method: Requested authentication method for the token endpoint. It can be set to `"none"`, `"client_secret_post"`, `"client_secret_basic"`, `"client_secret_jwt"`.
        :param pulumi.Input[str] tos_uri: URI to web page providing client tos (terms of service).
        :param pulumi.Input[str] type: The type of OAuth application.
        :param pulumi.Input[list] users: The users assigned to the application. It is recommended not to use this and instead use `app.User`.

        The **users** object supports the following:

          * `id` (`pulumi.Input[str]`)
          * `password` (`pulumi.Input[str]`)
          * `scope` (`pulumi.Input[str]`)
          * `username` (`pulumi.Input[str]`)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["auto_key_rotation"] = auto_key_rotation
        __props__["auto_submit_toolbar"] = auto_submit_toolbar
        __props__["client_basic_secret"] = client_basic_secret
        __props__["client_id"] = client_id
        __props__["client_secret"] = client_secret
        __props__["client_uri"] = client_uri
        __props__["consent_method"] = consent_method
        __props__["custom_client_id"] = custom_client_id
        __props__["grant_types"] = grant_types
        __props__["groups"] = groups
        __props__["hide_ios"] = hide_ios
        __props__["hide_web"] = hide_web
        __props__["issuer_mode"] = issuer_mode
        __props__["label"] = label
        __props__["login_uri"] = login_uri
        __props__["logo_uri"] = logo_uri
        __props__["name"] = name
        __props__["omit_secret"] = omit_secret
        __props__["policy_uri"] = policy_uri
        __props__["post_logout_redirect_uris"] = post_logout_redirect_uris
        __props__["profile"] = profile
        __props__["redirect_uris"] = redirect_uris
        __props__["response_types"] = response_types
        __props__["sign_on_mode"] = sign_on_mode
        __props__["status"] = status
        __props__["token_endpoint_auth_method"] = token_endpoint_auth_method
        __props__["tos_uri"] = tos_uri
        __props__["type"] = type
        __props__["users"] = users
        return OAuth(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class SocialIdp(pulumi.CustomResource):
    account_link_action: pulumi.Output[str]
    account_link_group_includes: pulumi.Output[list]
    authorization_binding: pulumi.Output[str]
    authorization_url: pulumi.Output[str]
    client_id: pulumi.Output[str]
    client_secret: pulumi.Output[str]
    deprovisioned_action: pulumi.Output[str]
    groups_action: pulumi.Output[str]
    groups_assignments: pulumi.Output[list]
    groups_attribute: pulumi.Output[str]
    groups_filters: pulumi.Output[list]
    issuer_mode: pulumi.Output[str]
    """
    Indicates whether Okta uses the original Okta org domain URL, or a custom domain URL
    """
    match_attribute: pulumi.Output[str]
    match_type: pulumi.Output[str]
    max_clock_skew: pulumi.Output[float]
    name: pulumi.Output[str]
    """
    name of idp
    """
    profile_master: pulumi.Output[bool]
    protocol_type: pulumi.Output[str]
    provisioning_action: pulumi.Output[str]
    request_signature_algorithm: pulumi.Output[str]
    """
    algorithm to use to sign requests
    """
    request_signature_scope: pulumi.Output[str]
    """
    algorithm to use to sign response
    """
    response_signature_algorithm: pulumi.Output[str]
    """
    algorithm to use to sign requests
    """
    response_signature_scope: pulumi.Output[str]
    """
    algorithm to use to sign response
    """
    scopes: pulumi.Output[list]
    status: pulumi.Output[str]
    subject_match_attribute: pulumi.Output[str]
    subject_match_type: pulumi.Output[str]
    suspended_action: pulumi.Output[str]
    token_binding: pulumi.Output[str]
    token_url: pulumi.Output[str]
    type: pulumi.Output[str]
    username_template: pulumi.Output[str]
    def __init__(__self__, resource_name, opts=None, account_link_action=None, account_link_group_includes=None, client_id=None, client_secret=None, deprovisioned_action=None, groups_action=None, groups_assignments=None, groups_attribute=None, groups_filters=None, issuer_mode=None, match_attribute=None, match_type=None, max_clock_skew=None, name=None, profile_master=None, protocol_type=None, provisioning_action=None, request_signature_algorithm=None, request_signature_scope=None, response_signature_algorithm=None, response_signature_scope=None, scopes=None, status=None, subject_match_attribute=None, subject_match_type=None, suspended_action=None, type=None, username_template=None, __props__=None, __name__=None, __opts__=None):
        """
        Create a SocialIdp resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] issuer_mode: Indicates whether Okta uses the original Okta org domain URL, or a custom domain URL
        :param pulumi.Input[str] name: name of idp
        :param pulumi.Input[str] request_signature_algorithm: algorithm to use to sign requests
        :param pulumi.Input[str] request_signature_scope: algorithm to use to sign response
        :param pulumi.Input[str] response_signature_algorithm: algorithm to use to sign requests
        :param pulumi.Input[str] response_signature_scope: algorithm to use to sign response
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['account_link_action'] = account_link_action
            __props__['account_link_group_includes'] = account_link_group_includes
            __props__['client_id'] = client_id
            __props__['client_secret'] = client_secret
            __props__['deprovisioned_action'] = deprovisioned_action
            __props__['groups_action'] = groups_action
            __props__['groups_assignments'] = groups_assignments
            __props__['groups_attribute'] = groups_attribute
            __props__['groups_filters'] = groups_filters
            __props__['issuer_mode'] = issuer_mode
            __props__['match_attribute'] = match_attribute
            __props__['match_type'] = match_type
            __props__['max_clock_skew'] = max_clock_skew
            __props__['name'] = name
            __props__['profile_master'] = profile_master
            __props__['protocol_type'] = protocol_type
            __props__['provisioning_action'] = provisioning_action
            __props__['request_signature_algorithm'] = request_signature_algorithm
            __props__['request_signature_scope'] = request_signature_scope
            __props__['response_signature_algorithm'] = response_signature_algorithm
            __props__['response_signature_scope'] = response_signature_scope
            if scopes is None:
                raise TypeError("Missing required property 'scopes'")
            __props__['scopes'] = scopes
            __props__['status'] = status
            __props__['subject_match_attribute'] = subject_match_attribute
            __props__['subject_match_type'] = subject_match_type
            __props__['suspended_action'] = suspended_action
            if type is None:
                raise TypeError("Missing required property 'type'")
            __props__['type'] = type
            __props__['username_template'] = username_template
            __props__['authorization_binding'] = None
            __props__['authorization_url'] = None
            __props__['token_binding'] = None
            __props__['token_url'] = None
        super(SocialIdp, __self__).__init__(
            'okta:deprecated/socialIdp:SocialIdp',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, account_link_action=None, account_link_group_includes=None, authorization_binding=None, authorization_url=None, client_id=None, client_secret=None, deprovisioned_action=None, groups_action=None, groups_assignments=None, groups_attribute=None, groups_filters=None, issuer_mode=None, match_attribute=None, match_type=None, max_clock_skew=None, name=None, profile_master=None, protocol_type=None, provisioning_action=None, request_signature_algorithm=None, request_signature_scope=None, response_signature_algorithm=None, response_signature_scope=None, scopes=None, status=None, subject_match_attribute=None, subject_match_type=None, suspended_action=None, token_binding=None, token_url=None, type=None, username_template=None):
        """
        Get an existing SocialIdp resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] issuer_mode: Indicates whether Okta uses the original Okta org domain URL, or a custom domain URL
        :param pulumi.Input[str] name: name of idp
        :param pulumi.Input[str] request_signature_algorithm: algorithm to use to sign requests
        :param pulumi.Input[str] request_signature_scope: algorithm to use to sign response
        :param pulumi.Input[str] response_signature_algorithm: algorithm to use to sign requests
        :param pulumi.Input[str] response_signature_scope: algorithm to use to sign response
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["account_link_action"] = account_link_action
        __props__["account_link_group_includes"] = account_link_group_includes
        __props__["authorization_binding"] = authorization_binding
        __props__["authorization_url"] = authorization_url
        __props__["client_id"] = client_id
        __props__["client_secret"] = client_secret
        __props__["deprovisioned_action"] = deprovisioned_action
        __props__["groups_action"] = groups_action
        __props__["groups_assignments"] = groups_assignments
        __props__["groups_attribute"] = groups_attribute
        __props__["groups_filters"] = groups_filters
        __props__["issuer_mode"] = issuer_mode
        __props__["match_attribute"] = match_attribute
        __props__["match_type"] = match_type
        __props__["max_clock_skew"] = max_clock_skew
        __props__["name"] = name
        __props__["profile_master"] = profile_master
        __props__["protocol_type"] = protocol_type
        __props__["provisioning_action"] = provisioning_action
        __props__["request_signature_algorithm"] = request_signature_algorithm
        __props__["request_signature_scope"] = request_signature_scope
        __props__["response_signature_algorithm"] = response_signature_algorithm
        __props__["response_signature_scope"] = response_signature_scope
        __props__["scopes"] = scopes
        __props__["status"] = status
        __props__["subject_match_attribute"] = subject_match_attribute
        __props__["subject_match_type"] = subject_match_type
        __props__["suspended_action"] = suspended_action
        __props__["token_binding"] = token_binding
        __props__["token_url"] = token_url
        __props__["type"] = type
        __props__["username_template"] = username_template
        return SocialIdp(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class GetEveryoneGroupResult:
    """
    A collection of values returned by getEveryoneGroup.
    """
    def __init__(__self__, id=None, include_users=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        The provider-assigned unique ID for this managed resource.
        """
        if include_users and not isinstance(include_users, bool):
            raise TypeError("Expected argument 'include_users' to be a bool")
        __self__.include_users = include_users
class AwaitableGetEveryoneGroupResult(GetEveryoneGroupResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEveryoneGroupResult(
            id=self.id,
            include_users=self.include_users)

def get_everyone_group(include_users=None,opts=None):
    """
    Use this data source to retrieve the Everyone group from Okta. The same can be achieved with the `group.Group` data source with `name = "Everyone"`. This is simply a shortcut.

    ## Example Usage



    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.group.get_everyone_group()
    ```
    """
    __args__ = dict()


    __args__['includeUsers'] = include_users
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('okta:group/getEveryoneGroup:getEveryoneGroup', __args__, opts=opts).value

    return AwaitableGetEveryoneGroupResult(
        id=__ret__.get('id'),
        include_users=__ret__.get('includeUsers'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class GetSamlResult:
    """
    A collection of values returned by getSaml.
    """
    def __init__(__self__, accessibility_error_redirect_url=None, accessibility_login_redirect_url=None, accessibility_self_service=None, active_only=None, app_settings_json=None, assertion_signed=None, attribute_statements=None, audience=None, authn_context_class_ref=None, auto_submit_toolbar=None, default_relay_state=None, description=None, destination=None, digest_algorithm=None, features=None, hide_ios=None, hide_web=None, honor_force_authn=None, id=None, idp_issuer=None, key_id=None, label=None, label_prefix=None, name=None, recipient=None, request_compressed=None, response_signed=None, signature_algorithm=None, sp_issuer=None, sso_url=None, status=None, subject_name_id_format=None, subject_name_id_template=None, user_name_template=None, user_name_template_suffix=None, user_name_template_type=None):
        if accessibility_error_redirect_url and not isinstance(accessibility_error_redirect_url, str):
            raise TypeError("Expected argument 'accessibility_error_redirect_url' to be a str")
        __self__.accessibility_error_redirect_url = accessibility_error_redirect_url
        """
        Custom error page URL.
        """
        if accessibility_login_redirect_url and not isinstance(accessibility_login_redirect_url, str):
            raise TypeError("Expected argument 'accessibility_login_redirect_url' to be a str")
        __self__.accessibility_login_redirect_url = accessibility_login_redirect_url
        """
        Custom login page URL.
        """
        if accessibility_self_service and not isinstance(accessibility_self_service, bool):
            raise TypeError("Expected argument 'accessibility_self_service' to be a bool")
        __self__.accessibility_self_service = accessibility_self_service
        """
        Enable self service.
        """
        if active_only and not isinstance(active_only, bool):
            raise TypeError("Expected argument 'active_only' to be a bool")
        __self__.active_only = active_only
        if app_settings_json and not isinstance(app_settings_json, str):
            raise TypeError("Expected argument 'app_settings_json' to be a str")
        __self__.app_settings_json = app_settings_json
        """
        Application settings in JSON format.
        """
        if assertion_signed and not isinstance(assertion_signed, bool):
            raise TypeError("Expected argument 'assertion_signed' to be a bool")
        __self__.assertion_signed = assertion_signed
        """
        Determines whether the SAML assertion is digitally signed.
        """
        if attribute_statements and not isinstance(attribute_statements, list):
            raise TypeError("Expected argument 'attribute_statements' to be a list")
        __self__.attribute_statements = attribute_statements
        """
        SAML Attribute statements.
        """
        if audience and not isinstance(audience, str):
            raise TypeError("Expected argument 'audience' to be a str")
        __self__.audience = audience
        """
        Audience restriction.
        """
        if authn_context_class_ref and not isinstance(authn_context_class_ref, str):
            raise TypeError("Expected argument 'authn_context_class_ref' to be a str")
        __self__.authn_context_class_ref = authn_context_class_ref
        """
        Identifies the SAML authentication context class for the assertion’s authentication statement.
        """
        if auto_submit_toolbar and not isinstance(auto_submit_toolbar, bool):
            raise TypeError("Expected argument 'auto_submit_toolbar' to be a bool")
        __self__.auto_submit_toolbar = auto_submit_toolbar
        """
        Display auto submit toolbar.
        """
        if default_relay_state and not isinstance(default_relay_state, str):
            raise TypeError("Expected argument 'default_relay_state' to be a str")
        __self__.default_relay_state = default_relay_state
        """
        Identifies a specific application resource in an IDP initiated SSO scenario.
        """
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        __self__.description = description
        """
        description of application.
        """
        if destination and not isinstance(destination, str):
            raise TypeError("Expected argument 'destination' to be a str")
        __self__.destination = destination
        """
        Identifies the location where the SAML response is intended to be sent inside of the SAML assertion.
        """
        if digest_algorithm and not isinstance(digest_algorithm, str):
            raise TypeError("Expected argument 'digest_algorithm' to be a str")
        __self__.digest_algorithm = digest_algorithm
        """
        Determines the digest algorithm used to digitally sign the SAML assertion and response.
        """
        if features and not isinstance(features, list):
            raise TypeError("Expected argument 'features' to be a list")
        __self__.features = features
        """
        features enabled.
        """
        if hide_ios and not isinstance(hide_ios, bool):
            raise TypeError("Expected argument 'hide_ios' to be a bool")
        __self__.hide_ios = hide_ios
        """
        Do not display application icon on mobile app.
        """
        if hide_web and not isinstance(hide_web, bool):
            raise TypeError("Expected argument 'hide_web' to be a bool")
        __self__.hide_web = hide_web
        """
        Do not display application icon to users
        """
        if honor_force_authn and not isinstance(honor_force_authn, bool):
            raise TypeError("Expected argument 'honor_force_authn' to be a bool")
        __self__.honor_force_authn = honor_force_authn
        """
        Prompt user to re-authenticate if SP asks for it.
        """
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        id of application.
        """
        if idp_issuer and not isinstance(idp_issuer, str):
            raise TypeError("Expected argument 'idp_issuer' to be a str")
        __self__.idp_issuer = idp_issuer
        """
        SAML issuer ID.
        """
        if key_id and not isinstance(key_id, str):
            raise TypeError("Expected argument 'key_id' to be a str")
        __self__.key_id = key_id
        """
        Certificate key ID.
        """
        if label and not isinstance(label, str):
            raise TypeError("Expected argument 'label' to be a str")
        __self__.label = label
        """
        label of application.
        """
        if label_prefix and not isinstance(label_prefix, str):
            raise TypeError("Expected argument 'label_prefix' to be a str")
        __self__.label_prefix = label_prefix
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        __self__.name = name
        """
        name of application.
        """
        if recipient and not isinstance(recipient, str):
            raise TypeError("Expected argument 'recipient' to be a str")
        __self__.recipient = recipient
        """
        The location where the app may present the SAML assertion.
        """
        if request_compressed and not isinstance(request_compressed, bool):
            raise TypeError("Expected argument 'request_compressed' to be a bool")
        __self__.request_compressed = request_compressed
        """
        Denotes whether the request is compressed or not.
        """
        if response_signed and not isinstance(response_signed, bool):
            raise TypeError("Expected argument 'response_signed' to be a bool")
        __self__.response_signed = response_signed
        """
        Determines whether the SAML auth response message is digitally signed.
        """
        if signature_algorithm and not isinstance(signature_algorithm, str):
            raise TypeError("Expected argument 'signature_algorithm' to be a str")
        __self__.signature_algorithm = signature_algorithm
        """
        Signature algorithm used ot digitally sign the assertion and response.
        """
        if sp_issuer and not isinstance(sp_issuer, str):
            raise TypeError("Expected argument 'sp_issuer' to be a str")
        __self__.sp_issuer = sp_issuer
        """
        SAML service provider issuer.
        """
        if sso_url and not isinstance(sso_url, str):
            raise TypeError("Expected argument 'sso_url' to be a str")
        __self__.sso_url = sso_url
        """
        Single Sign on Url.
        """
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        __self__.status = status
        """
        status of application.
        """
        if subject_name_id_format and not isinstance(subject_name_id_format, str):
            raise TypeError("Expected argument 'subject_name_id_format' to be a str")
        __self__.subject_name_id_format = subject_name_id_format
        """
        Identifies the SAML processing rules.
        """
        if subject_name_id_template and not isinstance(subject_name_id_template, str):
            raise TypeError("Expected argument 'subject_name_id_template' to be a str")
        __self__.subject_name_id_template = subject_name_id_template
        """
        Template for app user's username when a user is assigned to the app.
        """
        if user_name_template and not isinstance(user_name_template, str):
            raise TypeError("Expected argument 'user_name_template' to be a str")
        __self__.user_name_template = user_name_template
        """
        Username template.
        """
        if user_name_template_suffix and not isinstance(user_name_template_suffix, str):
            raise TypeError("Expected argument 'user_name_template_suffix' to be a str")
        __self__.user_name_template_suffix = user_name_template_suffix
        """
        Username template suffix.
        """
        if user_name_template_type and not isinstance(user_name_template_type, str):
            raise TypeError("Expected argument 'user_name_template_type' to be a str")
        __self__.user_name_template_type = user_name_template_type
        """
        Username template type.
        """
class AwaitableGetSamlResult(GetSamlResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSamlResult(
            accessibility_error_redirect_url=self.accessibility_error_redirect_url,
            accessibility_login_redirect_url=self.accessibility_login_redirect_url,
            accessibility_self_service=self.accessibility_self_service,
            active_only=self.active_only,
            app_settings_json=self.app_settings_json,
            assertion_signed=self.assertion_signed,
            attribute_statements=self.attribute_statements,
            audience=self.audience,
            authn_context_class_ref=self.authn_context_class_ref,
            auto_submit_toolbar=self.auto_submit_toolbar,
            default_relay_state=self.default_relay_state,
            description=self.description,
            destination=self.destination,
            digest_algorithm=self.digest_algorithm,
            features=self.features,
            hide_ios=self.hide_ios,
            hide_web=self.hide_web,
            honor_force_authn=self.honor_force_authn,
            id=self.id,
            idp_issuer=self.idp_issuer,
            key_id=self.key_id,
            label=self.label,
            label_prefix=self.label_prefix,
            name=self.name,
            recipient=self.recipient,
            request_compressed=self.request_compressed,
            response_signed=self.response_signed,
            signature_algorithm=self.signature_algorithm,
            sp_issuer=self.sp_issuer,
            sso_url=self.sso_url,
            status=self.status,
            subject_name_id_format=self.subject_name_id_format,
            subject_name_id_template=self.subject_name_id_template,
            user_name_template=self.user_name_template,
            user_name_template_suffix=self.user_name_template_suffix,
            user_name_template_type=self.user_name_template_type)

def get_saml(accessibility_error_redirect_url=None,accessibility_login_redirect_url=None,accessibility_self_service=None,active_only=None,app_settings_json=None,assertion_signed=None,attribute_statements=None,audience=None,authn_context_class_ref=None,auto_submit_toolbar=None,default_relay_state=None,destination=None,digest_algorithm=None,features=None,hide_ios=None,hide_web=None,honor_force_authn=None,id=None,idp_issuer=None,label=None,label_prefix=None,recipient=None,request_compressed=None,response_signed=None,signature_algorithm=None,sp_issuer=None,sso_url=None,subject_name_id_format=None,subject_name_id_template=None,user_name_template=None,user_name_template_suffix=None,user_name_template_type=None,opts=None):
    """
    Use this data source to retrieve the collaborators for a given repository.

    ## Example Usage



    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.app.get_saml(label="Example App")
    ```



    :param str accessibility_error_redirect_url: Custom error page URL.
    :param str accessibility_login_redirect_url: Custom login page URL.
    :param bool accessibility_self_service: Enable self service.
    :param bool active_only: tells the provider to query for only `ACTIVE` applications.
    :param str app_settings_json: Application settings in JSON format.
    :param bool assertion_signed: Determines whether the SAML assertion is digitally signed.
    :param list attribute_statements: SAML Attribute statements.
    :param str audience: Audience restriction.
    :param str authn_context_class_ref: Identifies the SAML authentication context class for the assertion’s authentication statement.
    :param bool auto_submit_toolbar: Display auto submit toolbar.
    :param str default_relay_state: Identifies a specific application resource in an IDP initiated SSO scenario.
    :param str destination: Identifies the location where the SAML response is intended to be sent inside of the SAML assertion.
    :param str digest_algorithm: Determines the digest algorithm used to digitally sign the SAML assertion and response.
    :param list features: features enabled.
    :param bool hide_ios: Do not display application icon on mobile app.
    :param bool hide_web: Do not display application icon to users
    :param bool honor_force_authn: Prompt user to re-authenticate if SP asks for it.
    :param str id: `id` of application to retrieve, conflicts with `label` and `label_prefix`.
    :param str idp_issuer: SAML issuer ID.
    :param str label: The label of the app to retrieve, conflicts with `label_prefix` and `id`.
    :param str label_prefix: Label prefix of the app to retrieve, conflicts with `label` and `id`. This will tell the provider to do a `starts with` query as opposed to an `equals` query.
    :param str recipient: The location where the app may present the SAML assertion.
    :param bool request_compressed: Denotes whether the request is compressed or not.
    :param bool response_signed: Determines whether the SAML auth response message is digitally signed.
    :param str signature_algorithm: Signature algorithm used ot digitally sign the assertion and response.
    :param str sp_issuer: SAML service provider issuer.
    :param str sso_url: Single Sign on Url.
    :param str subject_name_id_format: Identifies the SAML processing rules.
    :param str subject_name_id_template: Template for app user's username when a user is assigned to the app.
    :param str user_name_template: Username template.
    :param str user_name_template_suffix: Username template suffix.
    :param str user_name_template_type: Username template type.

    The **attribute_statements** object supports the following:

      * `filterType` (`str`)
      * `filterValue` (`str`)
      * `name` (`str`) - name of application.
      * `namespace` (`str`)
      * `type` (`str`)
      * `values` (`list`)
    """
    __args__ = dict()


    __args__['accessibilityErrorRedirectUrl'] = accessibility_error_redirect_url
    __args__['accessibilityLoginRedirectUrl'] = accessibility_login_redirect_url
    __args__['accessibilitySelfService'] = accessibility_self_service
    __args__['activeOnly'] = active_only
    __args__['appSettingsJson'] = app_settings_json
    __args__['assertionSigned'] = assertion_signed
    __args__['attributeStatements'] = attribute_statements
    __args__['audience'] = audience
    __args__['authnContextClassRef'] = authn_context_class_ref
    __args__['autoSubmitToolbar'] = auto_submit_toolbar
    __args__['defaultRelayState'] = default_relay_state
    __args__['destination'] = destination
    __args__['digestAlgorithm'] = digest_algorithm
    __args__['features'] = features
    __args__['hideIos'] = hide_ios
    __args__['hideWeb'] = hide_web
    __args__['honorForceAuthn'] = honor_force_authn
    __args__['id'] = id
    __args__['idpIssuer'] = idp_issuer
    __args__['label'] = label
    __args__['labelPrefix'] = label_prefix
    __args__['recipient'] = recipient
    __args__['requestCompressed'] = request_compressed
    __args__['responseSigned'] = response_signed
    __args__['signatureAlgorithm'] = signature_algorithm
    __args__['spIssuer'] = sp_issuer
    __args__['ssoUrl'] = sso_url
    __args__['subjectNameIdFormat'] = subject_name_id_format
    __args__['subjectNameIdTemplate'] = subject_name_id_template
    __args__['userNameTemplate'] = user_name_template
    __args__['userNameTemplateSuffix'] = user_name_template_suffix
    __args__['userNameTemplateType'] = user_name_template_type
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('okta:app/getSaml:getSaml', __args__, opts=opts).value

    return AwaitableGetSamlResult(
        accessibility_error_redirect_url=__ret__.get('accessibilityErrorRedirectUrl'),
        accessibility_login_redirect_url=__ret__.get('accessibilityLoginRedirectUrl'),
        accessibility_self_service=__ret__.get('accessibilitySelfService'),
        active_only=__ret__.get('activeOnly'),
        app_settings_json=__ret__.get('appSettingsJson'),
        assertion_signed=__ret__.get('assertionSigned'),
        attribute_statements=__ret__.get('attributeStatements'),
        audience=__ret__.get('audience'),
        authn_context_class_ref=__ret__.get('authnContextClassRef'),
        auto_submit_toolbar=__ret__.get('autoSubmitToolbar'),
        default_relay_state=__ret__.get('defaultRelayState'),
        description=__ret__.get('description'),
        destination=__ret__.get('destination'),
        digest_algorithm=__ret__.get('digestAlgorithm'),
        features=__ret__.get('features'),
        hide_ios=__ret__.get('hideIos'),
        hide_web=__ret__.get('hideWeb'),
        honor_force_authn=__ret__.get('honorForceAuthn'),
        id=__ret__.get('id'),
        idp_issuer=__ret__.get('idpIssuer'),
        key_id=__ret__.get('keyId'),
        label=__ret__.get('label'),
        label_prefix=__ret__.get('labelPrefix'),
        name=__ret__.get('name'),
        recipient=__ret__.get('recipient'),
        request_compressed=__ret__.get('requestCompressed'),
        response_signed=__ret__.get('responseSigned'),
        signature_algorithm=__ret__.get('signatureAlgorithm'),
        sp_issuer=__ret__.get('spIssuer'),
        sso_url=__ret__.get('ssoUrl'),
        status=__ret__.get('status'),
        subject_name_id_format=__ret__.get('subjectNameIdFormat'),
        subject_name_id_template=__ret__.get('subjectNameIdTemplate'),
        user_name_template=__ret__.get('userNameTemplate'),
        user_name_template_suffix=__ret__.get('userNameTemplateSuffix'),
        user_name_template_type=__ret__.get('userNameTemplateType'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class Hook(pulumi.CustomResource):
    auth: pulumi.Output[dict]
    """
    Authentication required for inline hook request.

      * `key` (`str`) - Key to use for authentication, usually the header name, for example `"Authorization"`.
      * `type` (`str`) - The type of hook to trigger. Currently only `"HTTP"` is supported.
      * `value` (`str`) - Authentication secret.
    """
    channel: pulumi.Output[dict]
    """
    Details of the endpoint the inline hook will hit.

      * `method` (`str`) - The request method to use. Default is `"POST"`.
      * `type` (`bool`) - The type of hook to trigger. Currently only `"HTTP"` is supported.
      * `uri` (`str`) - The URI the hook will hit.
      * `version` (`str`) - The version of the endpoint.
    """
    headers: pulumi.Output[list]
    """
    Map of headers to send along in inline hook request.

      * `key` (`str`) - Key to use for authentication, usually the header name, for example `"Authorization"`.
      * `value` (`str`) - Authentication secret.
    """
    name: pulumi.Output[str]
    """
    The inline hook display name.
    """
    status: pulumi.Output[str]
    type: pulumi.Output[str]
    """
    The type of hook to trigger. Currently only `"HTTP"` is supported.
    """
    version: pulumi.Output[str]
    """
    The version of the endpoint.
    """
    def __init__(__self__, resource_name, opts=None, auth=None, channel=None, headers=None, name=None, status=None, type=None, version=None, __props__=None, __name__=None, __opts__=None):
        """
        Creates an inline hook.

        This resource allows you to create and configure an inline hook.

        ## Example Usage



        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.inline.Hook("example",
            auth={
                "key": "Authorization",
                "type": "HEADER",
                "value": "secret",
            },
            channel={
                "method": "POST",
                "uri": "https://example.com/test",
                "version": "1.0.0",
            },
            type="com.okta.oauth2.tokens.transform",
            version="1.0.1")
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] auth: Authentication required for inline hook request.
        :param pulumi.Input[dict] channel: Details of the endpoint the inline hook will hit.
        :param pulumi.Input[list] headers: Map of headers to send along in inline hook request.
        :param pulumi.Input[str] name: The inline hook display name.
        :param pulumi.Input[str] type: The type of hook to trigger. Currently only `"HTTP"` is supported.
        :param pulumi.Input[str] version: The version of the endpoint.

        The **auth** object supports the following:

          * `key` (`pulumi.Input[str]`) - Key to use for authentication, usually the header name, for example `"Authorization"`.
          * `type` (`pulumi.Input[str]`) - The type of hook to trigger. Currently only `"HTTP"` is supported.
          * `value` (`pulumi.Input[str]`) - Authentication secret.

        The **channel** object supports the following:

          * `method` (`pulumi.Input[str]`) - The request method to use. Default is `"POST"`.
          * `type` (`pulumi.Input[bool]`) - The type of hook to trigger. Currently only `"HTTP"` is supported.
          * `uri` (`pulumi.Input[str]`) - The URI the hook will hit.
          * `version` (`pulumi.Input[str]`) - The version of the endpoint.

        The **headers** object supports the following:

          * `key` (`pulumi.Input[str]`) - Key to use for authentication, usually the header name, for example `"Authorization"`.
          * `value` (`pulumi.Input[str]`) - Authentication secret.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['auth'] = auth
            __props__['channel'] = channel
            __props__['headers'] = headers
            __props__['name'] = name
            __props__['status'] = status
            if type is None:
                raise TypeError("Missing required property 'type'")
            __props__['type'] = type
            if version is None:
                raise TypeError("Missing required property 'version'")
            __props__['version'] = version
        super(Hook, __self__).__init__(
            'okta:inline/hook:Hook',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, auth=None, channel=None, headers=None, name=None, status=None, type=None, version=None):
        """
        Get an existing Hook resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] auth: Authentication required for inline hook request.
        :param pulumi.Input[dict] channel: Details of the endpoint the inline hook will hit.
        :param pulumi.Input[list] headers: Map of headers to send along in inline hook request.
        :param pulumi.Input[str] name: The inline hook display name.
        :param pulumi.Input[str] type: The type of hook to trigger. Currently only `"HTTP"` is supported.
        :param pulumi.Input[str] version: The version of the endpoint.

        The **auth** object supports the following:

          * `key` (`pulumi.Input[str]`) - Key to use for authentication, usually the header name, for example `"Authorization"`.
          * `type` (`pulumi.Input[str]`) - The type of hook to trigger. Currently only `"HTTP"` is supported.
          * `value` (`pulumi.Input[str]`) - Authentication secret.

        The **channel** object supports the following:

          * `method` (`pulumi.Input[str]`) - The request method to use. Default is `"POST"`.
          * `type` (`pulumi.Input[bool]`) - The type of hook to trigger. Currently only `"HTTP"` is supported.
          * `uri` (`pulumi.Input[str]`) - The URI the hook will hit.
          * `version` (`pulumi.Input[str]`) - The version of the endpoint.

        The **headers** object supports the following:

          * `key` (`pulumi.Input[str]`) - Key to use for authentication, usually the header name, for example `"Authorization"`.
          * `value` (`pulumi.Input[str]`) - Authentication secret.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["auth"] = auth
        __props__["channel"] = channel
        __props__["headers"] = headers
        __props__["name"] = name
        __props__["status"] = status
        __props__["type"] = type
        __props__["version"] = version
        return Hook(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class Email(pulumi.CustomResource):
    default_language: pulumi.Output[str]
    """
    The default language, by default is set to `"en"`.
    """
    translations: pulumi.Output[list]
    """
    Set of translations for particular template.

      * `language` (`str`) - The language to map tthe template to.
      * `subject` (`str`) - The email subject line.
      * `template` (`str`) - The email body.
    """
    type: pulumi.Output[str]
    """
    Email template type
    """
    def __init__(__self__, resource_name, opts=None, default_language=None, translations=None, type=None, __props__=None, __name__=None, __opts__=None):
        """
        Creates an Okta Email Template.

        This resource allows you to create and configure an Okta Email Template.

        ## Example Usage



        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.template.Email("example",
            translations=[
                {
                    "language": "en",
                    "subject": "Stuff",
                    "template": f"Hi {user['firstName']},<br/><br/>Blah blah {reset_password_link}",
                },
                {
                    "language": "es",
                    "subject": "Cosas",
                    "template": f"Hola {user['firstName']},<br/><br/>Puedo ir al bano {reset_password_link}",
                },
            ],
            type="email.forgotPassword")
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] default_language: The default language, by default is set to `"en"`.
        :param pulumi.Input[list] translations: Set of translations for particular template.
        :param pulumi.Input[str] type: Email template type

        The **translations** object supports the following:

          * `language` (`pulumi.Input[str]`) - The language to map tthe template to.
          * `subject` (`pulumi.Input[str]`) - The email subject line.
          * `template` (`pulumi.Input[str]`) - The email body.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['default_language'] = default_language
            if translations is None:
                raise TypeError("Missing required property 'translations'")
            __props__['translations'] = translations
            if type is None:
                raise TypeError("Missing required property 'type'")
            __props__['type'] = type
        super(Email, __self__).__init__(
            'okta:template/email:Email',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, default_language=None, translations=None, type=None):
        """
        Get an existing Email resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] default_language: The default language, by default is set to `"en"`.
        :param pulumi.Input[list] translations: Set of translations for particular template.
        :param pulumi.Input[str] type: Email template type

        The **translations** object supports the following:

          * `language` (`pulumi.Input[str]`) - The language to map tthe template to.
          * `subject` (`pulumi.Input[str]`) - The email subject line.
          * `template` (`pulumi.Input[str]`) - The email body.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["default_language"] = default_language
        __props__["translations"] = translations
        __props__["type"] = type
        return Email(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop

